@@ -48,10 +48,10 @@ PURPOSE.  See the GNU General Public License for more details.
 		// This is case setting value
 		// Check type
 		if((typeof cur_value) != (typeof value)){
-			return false
+			return false;
 		}
 		
 		config[key] = value;
 		return true;
-	}
+	};
 })(cm);
