@@ -39,12 +39,6 @@ PURPOSE.  See the GNU General Public License for more details.
 		,tree           : {} // Facility Tree
 		,type_list      : {} // A list maps to type of facilities
 		,reserved_list  : {} // A list contains reserved facilities
-		,updateScopeTree: function(){
-			try{
-				__.repository.scope.content.tree.refreshData(this.get());
-			}catch(e){
-				}
-		}
 		,updateTreeViews: function(){
 			var _   = this
 			,views  = _.views
@@ -118,16 +112,13 @@ PURPOSE.  See the GNU General Public License for more details.
 						_.type_list = data_respond.typeList;
 					}
 					
-					// Update tree of repository scope view
-					_.updateScopeTree();
-					
 					// Call update the views which use facilityTree
 					_.updateTreeViews();
 				}else{
 					// Process error
 					cm.loadDataError();
 				}
-			}
+			};
 		}
 		,getData        : function(){
 			var _ = this
@@ -148,6 +139,12 @@ PURPOSE.  See the GNU General Public License for more details.
 			var _  = this
 			,views = _.views
 			;
+			var expand = 'var cClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-ico-scope-root.dynatree-exp-c.dynatree-ico-cf";'
+				+ 'var clClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-lastsib.dynatree-ico-scope-root.dynatree-exp-cl.dynatree-ico-cf";'
+				+ '$(cClassName + ">.dynatree-expander").click();'
+				+ '$(clClassName + ">.dynatree-expander").click();'
+				+ '$(".dynatree-active>a").focus();';
+			setTimeout(expand, 0);
 			
 			// Set vw_id
 			if(vw_id && ((typeof vw_id) == "string")){
@@ -155,7 +152,7 @@ PURPOSE.  See the GNU General Public License for more details.
 					views[views.length] = vw_id;
 				}
 			}
-			
+
 			// Return a cloned tree, set the composite is active and expanded
 			return $.extend(true, {}, _.tree, {
 				activate: true
