@@ -50,7 +50,7 @@ PURPOSE.  See the GNU General Public License for more details.
 			_bd_opt: bd_opt
 				
 			,// Process open this dialog
-			open: function(){
+			open: function(managerIp){
 				var i = this // dialog
 				,$dlg
 				,$bd // body dialog
@@ -108,7 +108,7 @@ PURPOSE.  See the GNU General Public License for more details.
 				$dlg.$bd = $bd;
 				
 				// Get grid data
-				$bd.jqGrid(i._bd_opt);
+				$bd.jqGrid(i._bd_opt, managerIp != undefined && managerIp != null && managerIp != "");
 			}
 			
 			,/*
