@@ -144,8 +144,6 @@ PURPOSE.  See the GNU General Public License for more details.
 		var token = /\\.|[dDjlNSwzWFmMntLoYyaABgGhHisueIOPTZcrU]/g
 		,timezone = /\b(?:[PMCEA][SDP]T|(?:Pacific|Mountain|Central|Eastern|Atlantic) (?:Standard|Daylight|Prevailing) Time|(?:GMT|UTC)(?:[-+]\d{4})?)\b/g
 		,timezoneClip = /[^-+\dA-Z]/g
-		,msDateRegExp = new RegExp("^\/Date\\((([-+])?[0-9]+)(([-+])([0-9]{2})([0-9]{2}))?\\)\/$")
-		,msMatch = ((typeof date === 'string') ? date.match(msDateRegExp) : null)
 		;
 
 		// Check valid of val
@@ -249,7 +247,7 @@ PURPOSE.  See the GNU General Public License for more details.
 		}
 
 		return html;
-	}
+	};
 	hnmDatetimePrecise.unformat = function(cellval) {
 		var time_value = 0;
 
@@ -416,7 +414,7 @@ PURPOSE.  See the GNU General Public License for more details.
 		}
 		
 		return value;
-	}
+	};
 	
 	// Formatter
 	$.extend($.fn.fmatter, {
@@ -445,8 +443,7 @@ PURPOSE.  See the GNU General Public License for more details.
 		 * Scope type
 		 */
 		hnmScope : function(val, opts, row) {
-			var type
-			,formatoptions
+			var formatoptions
 			,__ = cm
 			,fclt_id
 			,icon
@@ -737,7 +734,7 @@ PURPOSE.  See the GNU General Public License for more details.
 					icon_check = "ui-icon-hnm-unchecked";
 				}
 				
-				return __.getIconStr(icon_check)
+				return __.getIconStr(icon_check);
 			}else{
 				// Create input: mode create or edit
 				if (val) {
@@ -748,7 +745,7 @@ PURPOSE.  See the GNU General Public License for more details.
 					"<input type='checkbox' value='true'"
 					,str_chk
 					,">"
-				].join("")
+				].join("");
 			}
 		}
 		
@@ -777,7 +774,7 @@ PURPOSE.  See the GNU General Public License for more details.
 			if((val.value !== undefined) && (val.value !== null)){
 				value = val.value;
 			}else{
-				value = ""
+				value = "";
 			}
 			
 			// Get option
