@@ -153,7 +153,7 @@ PURPOSE.  See the GNU General Public License for more details.
 			
 			// Check selector is get
 			if(selr){
-				return __.selr2Per(selr)
+				return __.selr2Per(selr);
 			}
 			
 			return false;
@@ -164,7 +164,6 @@ PURPOSE.  See the GNU General Public License for more details.
 		 */
 		addView: function(vw_nm){
 			var __  = this
-			,__ctn  = __.$ctn
 			,per_nm = __.getActiveTab()
 			;
 			// Check id
@@ -387,7 +386,7 @@ $(document).ready(function(){
 				event.preventDefault();
 			}
 		}
-	}
+	};
 	
 	if(window.addEventListener){
 		// Adding the event onMouseScroll for Mozilla
@@ -400,7 +399,7 @@ $(document).ready(function(){
 			}else{
 				onMouseWheel(e);
 			}
-		}
+		};
 	}
 	
 	/*
