@@ -226,25 +226,46 @@ var cm = {
     ,/*
     * Get key of node in tree
     */
-    getNodeKey : function getNodeKey(node, facility_id) {
-        if (node.facilityId == facility_id){
-            if (node.children.length > 0) {
-                return node.key;
+    getNodeKey : function getNodeKey(node, facility_id, managerIp) {
+        var key = undefined;
+    	if (managerIp) {
+    		if (node.facilityId == facility_id && node.managerIp == managerIp){
+                if (node.children.length > 0) {
+                    return node.key;
+                } else {
+                    return;
+                }
             } else {
-                return;
-            }
-        } else {
-            var key;
-            $.each(node.children, function() {
-                key = getNodeKey(this, facility_id);
+                $.each(node.children, function() {
+                    key = getNodeKey(this, facility_id, managerIp);
+                    if (typeof key != 'undefined') {
+                        return false;
+                    }
+                });
+                
                 if (typeof key != 'undefined') {
-                    return false;
+                    return key;
                 }
-            });
-            
-            if (typeof key != 'undefined') {
-                return key;
             }
-        }
+    	} else {
+    		if (node.facilityId == facility_id){
+                if (node.children.length > 0) {
+                    return node.key;
+                } else {
+                    return;
+                }
+            } else {
+                $.each(node.children, function() {
+                    key = getNodeKey(this, facility_id);
+                    if (typeof key != 'undefined') {
+                        return false;
+                    }
+                });
+                
+                if (typeof key != 'undefined') {
+                    return key;
+                }
+            }
+    	}
     }
 };
\ No newline at end of file
