@@ -186,7 +186,7 @@ PURPOSE.  See the GNU General Public License for more details.
 				});
 			}
 		}else{
-			per._views = {}
+			per._views = {};
 		}
 		
 		/*
@@ -214,7 +214,7 @@ PURPOSE.  See the GNU General Public License for more details.
 		layouts.option = $.extend({}, setLayOpt(p_opts, lens, "layout2Selr"));
 		
 		// Storage number panel
-		layouts.lens = []
+		layouts.lens = [];
 		
 		/*
 		 * Construct for element layout
@@ -300,6 +300,70 @@ PURPOSE.  See the GNU General Public License for more details.
 			,assigned_scopes: [0, 1]
 			,node_property  : [1, 0]
 		}
+		,properties: {
+			repository_tree : {
+				data: null
+				,updateScopeTree: function(){
+					try{
+						__.repository.scope.content.tree.refreshData(this.get());
+					}catch(e){
+						}
+				}
+				,getData : function(){
+					var _   = this
+					,option = {
+						url      : "get_facility_tree"
+						,cache   : false
+						,dataType: "json"
+						,type    : "get"
+						,async   : false
+						,success : function(data_respond){
+							var tree_data;
+							
+							// Check validation of data_respond
+							if(!(__.checkJsonError(data_respond))){
+								return;
+							}
+							
+							if(tree_data = data_respond.facilityTree){
+								// Set tree data
+								_.data = tree_data;
+							}
+							__.repository.scope.content.tree.refreshData(_.get());
+						}
+						,error   : __.loadDataError
+					}
+					;
+					
+					// Get data of tree job
+					$.ajax(option);
+				}
+				,get     : function(){
+					var _ = this;
+					var expand = 'var cClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-ico-scope-root.dynatree-exp-c.dynatree-ico-cf";'
+						+ 'var clClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-lastsib.dynatree-ico-scope-root.dynatree-exp-cl.dynatree-ico-cf";'
+						+ '$(cClassName + ">.dynatree-expander").click();'
+						+ '$(clClassName + ">.dynatree-expander").click();'
+						+ '$(".dynatree-title:first").focus();'
+						+ '$(".dynatree-title:first").click();';
+					setTimeout(expand, 0);
+					// Check for update
+					if (_.data === null) {
+						_.data = {"addClass":"dynatree-ico-scope-root","children":[],"facilityId":"","isFolder":true,"key":"","managerIp":"","path":"","valid":true,"title":"","tooltip":""};
+						// Clone tree and return
+						return $.extend(true, {}, _.data, {expand : true});
+					}
+					if (_.data.length == 1) {
+						return _.data[0];
+					}
+					var dataArray = new Array(_.data.length);
+					for (var i = 0; i < _.data.length; i++) {
+						dataArray[i] = _.data[i];
+					}
+					return dataArray;
+				}
+			}
+		}
 	});
 	
 	/*
@@ -311,11 +375,12 @@ PURPOSE.  See the GNU General Public License for more details.
 				var _ = this // This perspective
 				,tree = {
 					title     : __.getLang("select_job")
-					,data     : _.job_tree.get()
+					,data     : _.job_tree.get(true)
 					,key      : "jobId"
 					,input    : input
 					,checkValue: function(value){
 						if(value && value.data && value.data.jobId){
+							$("#jobManager").val(value.data.managerIp);
 							return true;
 						}
 						return false;
@@ -353,7 +418,7 @@ PURPOSE.  See the GNU General Public License for more details.
 							
 							if(tree_data = data_respond.jobTree){
 								// Set tree data
-								_.data = tree_data[0];
+								_.data = tree_data;
 							}
 							/** Bug_154 */
 							__.jobmanagement.list.content.tree.refreshData(_.get());
@@ -371,19 +436,37 @@ PURPOSE.  See the GNU General Public License for more details.
 					// Get data of tree job
 					$.ajax(option);
 				}
-				,get     : function(){
+				,get     : function(isDialog){
 					var _ = this;
-					
+					var expand = 'var cClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-ico-job-composite.dynatree-exp-c.dynatree-ico-cf";'
+						+ 'var clClassName = ".dynatree-node.dynatree-folder.dynatree-has-children.dynatree-lastsib.dynatree-ico-job-composite.dynatree-exp-cl.dynatree-ico-cf";'
+						+ '$(cClassName + ">.dynatree-expander").click();'
+						+ '$(clClassName + ">.dynatree-expander").click();';
+					if (!isDialog) {
+						expand = expand + '$(".dynatree-focused>a").blur();';
+					} else {
+						expand = expand + '$(".dlg-cnt-div .dynatree-title:first").focus();'
+						+ '$(".dlg-cnt-div .dynatree-title:first").click();';
+					}
+					setTimeout(expand, 0);
 					// Check for update
 					if(_.data === null){
 						/** Bug_154 */
 						//_.getData(true);
 						_.data = {"addClass":"dynatree-ico-job-blank","children":[],"facilityId":"","isFolder":true,"jobId":"","path":"","jobunitId":"","title":"","tooltip":""};
 						/***********/
+						// Clone tree and return
+						return $.extend(true, {}, _.data, {expand : true});
+					} else {
+						if (_.data.length == 1) {
+							return _.data[0];
+						}
+						var dataArray = new Array(_.data.length);
+						for (var i = 0; i < _.data.length; i++) {
+							dataArray[i] = _.data[i];
+						}
+						return dataArray;
 					}
-					
-					// Clone tree and return
-					return $.extend(true, {}, _.data, {expand : true});
 				}
 			}
 		}
