@@ -18,9 +18,7 @@ PURPOSE.  See the GNU General Public License for more details.
  * Create (job management) FORWARD_FILE/FILE_TRANSFER
  */
 var fn = function(_view){
-	var __ = cm
-	,_pers = this
-	;
+	var __ = cm;
 	
 	var view = $.extend({}, __._fnview_grid, {
 		session_id : ""
@@ -28,6 +26,8 @@ var fn = function(_view){
 		,jobunit_id: ""
 		,forward_facility_id: ""
 		,recieve_facility_id: ""
+		,manager_ip : ""
+		,file_name  : ""
 		
 		,/*
 		 * Set caption of grid
@@ -35,11 +35,21 @@ var fn = function(_view){
 		setCaption: function(){
 			var _ = this;
 			
-			_.grid.setCaption([
-				__.getLang("session_id"), ": " , _.session_id
-				,",&nbsp;"
-				,__.getLang("job_id"), ": " , _.job_id
-			].join(""));
+			if (_.manager_ip && _.manager_ip != "") {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+					,",&nbsp;"
+					,__.getLang("job_id"), ": " , _.job_id
+	                ,",&nbsp;",
+	                __.getLang("manager"), ": " , _.manager_ip
+				].join(""));
+			} else {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+					,",&nbsp;"
+					,__.getLang("job_id"), ": " , _.job_id
+				].join(""));
+			}
 		}
 		
 		,/*
@@ -50,6 +60,7 @@ var fn = function(_view){
 			,session_id = _view.__session_id
 			,job_id     = _view.__job_id
 			,jobunit_id = _view.__jobunit_id
+			,manager_ip = _view.__manager_ip
 			,grid       = _.grid
 			;
 			
@@ -59,12 +70,14 @@ var fn = function(_view){
 				|| (jobunit_id !== _.jobunit_id)){
 				_.forward_facility_id = "";
 				_.recieve_facility_id = "";
+				_.file_name = "";
 			}
 			
 			// Get new value of session_id and job_id
 			_.session_id = session_id;
 			_.job_id     = job_id;
 			_.jobunit_id = jobunit_id;
+			_.manager_ip = manager_ip;
 			_.setCaption();
 			
 			// Check to clear?
@@ -78,7 +91,12 @@ var fn = function(_view){
 			
 			$("#load_grid_jobmanagement_forward_file").show();
 			// Reload grid
-			grid.refreshData({sessionId: session_id, jobId: job_id, jobunitId: jobunit_id});
+			grid.refreshData({
+				sessionId: session_id,
+				jobId: job_id,
+				jobunitId: jobunit_id,
+				managerIpForSearch: manager_ip
+			});
 		}
 		
 		,/*
@@ -120,6 +138,11 @@ var fn = function(_view){
 						
 						post_data.jobunitId = _.jobunit_id;
 					}
+					if (_view.__manager_ip) {
+						_.manager_ip = _view.__manager_ip;
+						
+						post_data.managerIpForSearch = _.manager_ip;
+					}
 					
 					// Set some options for grid
 					$.extend(data_respond, {
@@ -165,13 +188,16 @@ var fn = function(_view){
 						,loadComplete   : function(){
 							var curent_forward_facility_id= _.forward_facility_id;
 							var curent_recieve_facility_id= _.recieve_facility_id;
+							var file_name = _.file_name;
 
 							if (curent_forward_facility_id !== undefined && curent_forward_facility_id.length > 0
-								&& curent_recieve_facility_id !== undefined && curent_recieve_facility_id.length > 0) {
+								&& curent_recieve_facility_id !== undefined && curent_recieve_facility_id.length > 0
+								&& file_name !== undefined && file_name.length > 0) {
 
 								var in_file_transfer = $(grid).find('tr').filter(function(){
 									return ($(this).find('td:nth-child(4)').first().text() == curent_forward_facility_id
-											&& $(this).find('td:nth-child(6)').first().text() == curent_recieve_facility_id);
+											&& $(this).find('td:nth-child(6)').first().text() == curent_recieve_facility_id
+											&& $(this).find('td:nth-child(3)').first().text() == file_name);
 								});
 								
 								if (in_file_transfer.length > 0){
@@ -187,10 +213,12 @@ var fn = function(_view){
 							
 							_.forward_facility_id = $.jgrid.htmlEncode(row_data.srcFacilityId);
 							_.recieve_facility_id = $.jgrid.htmlEncode(row_data.destFacilityId);
+							_.file_name = $.jgrid.htmlEncode(row_data.fileName);
 						}
 					});
 					
-					grid.processData(data_respond);
+					grid.processData(data_respond, ['fileName', 'srcFacilityId', 'destFacilityId', 'startRerunTime', 'endSuspendTime'],
+							{startRerunTime: 'hnmDatetime', endSuspendTime: 'hnmDatetime'});
 					grid.controlSize();
 					_.setCaption();
 				}
