@@ -26,17 +26,18 @@ var fn = function(_view){
 		/*
 		 * Update data for jobDetail
 		 */
-		updateJobDetail: function(session_id){
-			var _ = this
-			,vw_dtl
-			;
+		updateJobDetail: function(session_id, manager_ip){
+			var vw_dtl;
 			
 			// Check whether view "job detail" exists
 			if(!(vw_dtl = _pers["job_detail"])){
 				return;
 			}
 			// Update data for view detail
-			vw_dtl.updateData({session_id: session_id});
+			vw_dtl.updateData({
+				session_id: session_id,
+				manager_ip: manager_ip ? manager_ip : ""
+			});
 		}
 		
 		,/*
@@ -74,26 +75,38 @@ var fn = function(_view){
 							
 							// Reload Job[JobDetail] after Job[History] be loaded
 							var curent_session_id  = _pers["job_detail"].__session_id;
+							var curent_manager_ip = _pers["job_detail"].__manager_ip;
 
 							if (curent_session_id !== undefined && curent_session_id.length > 0) {
-								var in_history = grid.find("td:nth-child(4)").filter(function() {
-									return $(this).text() == curent_session_id;
-								});
+								var in_history;
+								if (curent_manager_ip !== undefined && curent_manager_ip.length > 0) {
+									in_history = $(grid).find('tr').filter(function(){
+										return ($(this).find('td:nth-child(4)').first().text() == curent_session_id && 
+												$(this).find('td:nth-child(16)').first().text() == curent_manager_ip);
+									});
+								} else {
+									in_history = grid.find("td:nth-child(4)").filter(function() {
+										return $(this).text() == curent_session_id;
+									});
+								}
 								
 								var curent_jobunit_id = _pers["node_detail"].__jobunit_id;
 								var curent_job_id     = _pers["node_detail"].__job_id;
-								_.updateJobDetail('');
+								_.updateJobDetail('', '');
 								if (in_history.length > 0) {
 									if (curent_jobunit_id !== undefined && curent_jobunit_id.length > 0
 										&& curent_job_id !== undefined && curent_job_id.length > 0) {
 										_pers["node_detail"].__session_id = curent_session_id;
 										_pers["node_detail"].__jobunit_id = curent_jobunit_id;
 										_pers["node_detail"].__job_id = curent_job_id;
+										if (curent_manager_ip !== undefined && curent_manager_ip.length > 0) {
+											_pers["node_detail"].__manager_ip = curent_manager_ip;
+										}
 									}
 									
 									var row_id = $(in_history[0]).parent().attr('id');
 									grid.jqGrid('setSelection',row_id);
-									_.updateJobDetail(curent_session_id);
+									_.updateJobDetail(curent_session_id, curent_manager_ip);
 								}
 							}
 							
@@ -115,12 +128,16 @@ var fn = function(_view){
 							_.$btns.children("#start").removeClass("ui-state-default");
 							_.$btns.children("#stop").attr("disabled", false);
 							_.$btns.children("#stop").removeClass("ui-state-default");
-							
-							_.updateJobDetail($.jgrid.htmlEncode(row_data.sessionId));
+
+							_.updateJobDetail($.jgrid.htmlEncode(row_data.sessionId), row_data.manager);
 						}
 					});
 				
-					grid.processData(data_respond);
+					if (data_respond.colNames.length == 16) {
+						grid.processData(data_respond, ['sessionId', 'jobuinitId', 'jobId', 'manager']);
+					} else {
+						grid.processData(data_respond, ['sessionId', 'jobuinitId', 'jobId']);
+					}
 					grid.controlSize();
 					
 					// Bind context menu for grid(right click)
@@ -192,6 +209,9 @@ var fn = function(_view){
 						,open   : function(){
 							$(this).siblings('div.ui-dialog-buttonpane:first').find("button:eq(1)").focus();
 						}
+						,beforeClose : function() {
+							_.filter.storeValues();
+						}
 						,buttons: [
 							{
 								text  : __.getLang("clear")
@@ -209,7 +229,7 @@ var fn = function(_view){
 										$.extend(post_data, {filter: true});
 										
 										// Refresh data
-										_.grid.refreshData(post_data)
+										_.grid.refreshData(post_data, true);
 										
 										// Store filter active
 										_.filter_active = true;
@@ -319,7 +339,7 @@ var fn = function(_view){
 		 * Refresh data
 		 */
 		refreshData: function(){
-			this.grid.refreshData();
+			this.grid.refreshData(null, true);
 		}
 		
 		,/*
@@ -336,7 +356,7 @@ var fn = function(_view){
 			_btns.children("#filter").click(function(){
 				if(_.filter_active){
 					// Inactive filter for filter grid
-					_grid.refreshData({filter: false});
+					_grid.refreshData({filter: false}, true);
 					_grid.setCaption("&nbsp;");
 					
 					// Process CSS for button
@@ -350,7 +370,7 @@ var fn = function(_view){
 			
 			// Bind update grid data
 			_btns.children("#update").click(function(){
-				_.grid.refreshData();
+				_grid.refreshData(null, true);
 			});
 			
 			// Bind start button
@@ -386,6 +406,7 @@ var fn = function(_view){
 					,sessionId  : $.jgrid.htmlEncode(row_data.sessionId)
 					,jobunitId  : $.jgrid.htmlEncode(row_data.jobuinitId)
 					,jobId      : $.jgrid.htmlEncode(row_data.jobId)
+					,managerIpForSearch:row_data.manager
 				});
 				
 				// Set dialog title
@@ -418,6 +439,7 @@ var fn = function(_view){
 					,sessionId  : $.jgrid.htmlEncode(row_data.sessionId)
 					,jobunitId  : $.jgrid.htmlEncode(row_data.jobuinitId)
 					,jobId      : $.jgrid.htmlEncode(row_data.jobId)
+					,managerIpForSearch:row_data.manager
 				});
 				
 				// Set dialog title
