@@ -25,6 +25,7 @@ var fn = function(_view){
 	
 	var view = $.extend({}, __._fnview_grid, {
 		session_id: ""
+		,manager_ip:""
 		,load_flg    : false
 
 		,/*
@@ -33,16 +34,24 @@ var fn = function(_view){
 		setCaption: function(){
 			var _ = this;
 			
-			_.grid.setCaption([__.getLang("session_id"), ": " , _.session_id].join(""));
+			if (_.manager_ip && _.manager_ip != "") {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+					,",&nbsp;"
+	                ,__.getLang("manager"), ": " , _.manager_ip
+				].join(""));
+			} else {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+				].join(""));
+			}
 		}
 		
 		,/*
 		 * Update node detail
 		 */
-		updateNodeDetail: function(session_id, job_id, jobunit_id){
-			var _ = this
-			,vw_dtl
-			;
+		updateNodeDetail: function(session_id, job_id, jobunit_id, manager_ip){
+			var vw_dtl;
 			
 			// Check whether view "node detail" exists
 			if(!(vw_dtl = _pers["node_detail"])){
@@ -50,16 +59,19 @@ var fn = function(_view){
 			}
 			
 			// Update data for view
-			vw_dtl.updateData({session_id: session_id, job_id: job_id, jobunit_id: jobunit_id});
+			vw_dtl.updateData({
+				session_id: session_id,
+				job_id: job_id,
+				jobunit_id: jobunit_id,
+				manager_ip: manager_ip
+			});
 		}
 		
 		,/*
 		 * Update forward file
 		 */
-		updateForwardFile: function(session_id, job_id, jobunit_id){
-			var _ = this
-			,vw_dtl
-			;
+		updateForwardFile: function(session_id, job_id, jobunit_id, manager_ip){
+			var vw_dtl;
 			
 			// Check whether view "forward file" exists
 			if(!(vw_dtl = _pers["forward_file"])){
@@ -67,7 +79,12 @@ var fn = function(_view){
 			}
 			
 			// Update data for view
-			vw_dtl.updateData({session_id: session_id, job_id: job_id, jobunit_id: jobunit_id});
+			vw_dtl.updateData({
+				session_id: session_id,
+				job_id: job_id,
+				jobunit_id: jobunit_id,
+				manager_ip: manager_ip
+			});
 		}
 		
 		,/*
@@ -89,10 +106,12 @@ var fn = function(_view){
 		reloadGrid: function(){
 			var _       = this 
 			,session_id = _view.__session_id
+			,manager_ip = _view.__manager_ip
 			,grid       = _.grid
 			;
 			// Case updating
 			_.session_id = session_id;
+			_.manager_ip = manager_ip;
 			
 			// Set caption
 			_.setCaption();
@@ -110,14 +129,17 @@ var fn = function(_view){
 				_.$btns.children("#stop").addClass("ui-state-default");
 				
 				// Clear data of views which belong this view
-				_.updateNodeDetail("", "", "");
-				_.updateForwardFile("", "", "");
+				_.updateNodeDetail("", "", "", "");
+				_.updateForwardFile("", "", "", "");
                 _.load_flg = false;
 				return;
 			}
 			$("#load_grid_jobmanagement_job_detail").show();
 			// Reload grid
-			grid.refreshData({sessionId: session_id});
+			grid.refreshData({
+				sessionId: session_id,
+				managerIpForSearch: manager_ip
+			});
 		}
 		
 		,/*
@@ -143,12 +165,16 @@ var fn = function(_view){
 					}
 					
 					// Check session_id of view: control
-					if(_view.__session_id){
+					if (_view.__session_id) {
 						_.session_id = _view.__session_id;
 						
 						post_data.sessionId = _.session_id;
 					}
-					
+					if (_view.__manager_ip) {
+						_.manager_ip = _view.__manager_ip;
+						
+						post_data.managerIpForSearch = _.manager_ip;
+					}
 					// Set some options for grid
 					$.extend(data_respond, {
 						caption         : "&nbsp;"
@@ -188,13 +214,6 @@ var fn = function(_view){
 						}
 						,loadComplete   : function(){
 							var session_id = _view.__session_id;
-							
-							// Job[NodeDetail] and Job[ForwardFile] after 
-							// Job[JobDetail] loaded
-							
-							// Clear data of views which belong this view
-                            //_.updateNodeDetail("", "", "");
-							//_.updateForwardFile("", "", "");
 
 							var curent_session_id = _pers["node_detail"].__session_id;
 							var curent_jobunit_id = _pers["node_detail"].__jobunit_id;
@@ -209,14 +228,12 @@ var fn = function(_view){
 											$(this).find('td:nth-child(7)').first().text() == curent_jobunit_id);
 								});
 								
-								_.updateNodeDetail("", "", "");
-								_.updateForwardFile("", "", "");
+								_.updateNodeDetail("", "", "", "");
+								_.updateForwardFile("", "", "", "");
 								
 								if (curent_session_id == _.session_id && in_job_detail.length > 0) {
 									var row_id = $(in_job_detail[0]).attr('id');
 									grid.jqGrid('setSelection',row_id);
-									//_.updateNodeDetail(curent_session_id, curent_job_id, curent_jobunit_id);
-									//_.updateForwardFile(curent_session_id, curent_job_id, curent_jobunit_id);
 								}
 							}
 							
@@ -244,6 +261,7 @@ var fn = function(_view){
 							,session_id = _.session_id
 							,job_id     = $.jgrid.htmlEncode(row_data.jobId)
 							,jobunit_id = $.jgrid.htmlEncode(row_data.jobunitId)
+							,manager_ip = _.manager_ip;
 							;
 							
 							// Enable button "start" and "stop"
@@ -252,8 +270,8 @@ var fn = function(_view){
 							_.$btns.children("#stop").attr("disabled", false);
 							_.$btns.children("#stop").removeClass("ui-state-default");
 							
-							_.updateNodeDetail(session_id, job_id, jobunit_id);
-							_.updateForwardFile(session_id, job_id, jobunit_id);
+							_.updateNodeDetail(session_id, job_id, jobunit_id, manager_ip);
+							_.updateForwardFile(session_id, job_id, jobunit_id, manager_ip);
 						}
 					});
 					
@@ -419,6 +437,7 @@ var fn = function(_view){
 					,sessionId  : _view.__session_id
 					,jobunitId  : $.jgrid.htmlEncode(row_data.jobunitId)
 					,jobId      : $.jgrid.htmlEncode(row_data.jobId)
+					,managerIpForSearch:_.manager_ip
 				});
 				
 				// Set dialog title
@@ -451,6 +470,7 @@ var fn = function(_view){
 					,sessionId  : _view.__session_id
 					,jobunitId  : $.jgrid.htmlEncode(row_data.jobunitId)
 					,jobId      : $.jgrid.htmlEncode(row_data.jobId)
+					,managerIpForSearch:_.manager_ip
 				});
 				
 				// Set dialog title
