@@ -26,14 +26,19 @@ var fn = function(){
 	,jobName   = ""
 	,jobunitId = ""
 	,sel_jobid = ""
+	,manager_ip= ""
 	;
 	
 	 var view = $.extend({}, __._fnview_tree_grid, {
 		/*
 		 * Set caption of grid
 		 */
-		setCaption: function(path){
-			this.grid.setCaption([__.getLang("job"), ": " , path].join(""));
+		setCaption: function(path, managerIp){
+			if (managerIp == null || managerIp == "") {
+				this.grid.setCaption([__.getLang("job"), ": " , path].join(""));
+			} else {
+				this.grid.setCaption([__.getLang("job"), "(", managerIp, "): " , path].join(""));
+			}
 		}
 		
 		,/*
@@ -62,7 +67,7 @@ var fn = function(){
 			grid.setGridParam({data: data}).trigger("reloadGrid");
 			
 			// Set caption
-			_.setCaption(node_data.path);
+			_.setCaption(node_data.path, node_data.managerIp);
 		}
 		
 		,/*
@@ -80,6 +85,7 @@ var fn = function(){
 			if (jobId != "") {
 		 		jobName = node_data.jobData.jobName;
 			}
+			manager_ip = node_data.managerIp;
 			
 			// Check for setting status of run button
 			if((jobId != "")
@@ -156,10 +162,23 @@ var fn = function(){
 							// Check for select root case
 							if (jobunitId == ""){
 								var tree_data = _.getTree()
-								,len = tree_data.children.length
-								;
+								,len
+								,selected_tree;
+								if (tree_data.children) {
+									selected_tree = tree_data;
+								} else {
+									selected_tree = tree_data[0];
+									for (var i = 0; i < tree_data.length; i++) {
+										if (manager_ip == tree_data[i].managerIp) {
+											selected_tree = tree_data[i];
+											break;
+										}
+									}
+								}
+								
+								len = selected_tree.children.length;
 								for(var cnt = 0; cnt < len; cnt++){
-									var child = tree_data.children[cnt];
+									var child = selected_tree.children[cnt];
 									if (jobId == child.jobunitId){
 										
 										if ($.trim(child.addClass) == "dynatree-ico-forbidden_jobunit"){
@@ -267,8 +286,9 @@ var fn = function(){
 			var post_data = {
 					jobunitId: (jobunitId == "") ? jobId : jobunitId
 					,jobId   : jobId
+					,managerIpForSearch:manager_ip
 					,action  : "runjob"
-			}
+			};
 			$.ajax({
 				url      : "run_job"
 				,cache   : false
