@@ -19,15 +19,14 @@ PURPOSE.  See the GNU General Public License for more details.
  * Create (job management) NODE_DETAIL
  */
 var fn = function(_view){
-	var __ = cm
-	,_pers = this
-	;
+	var __ = cm;
 	
 	var view = $.extend({}, __._fnview_grid, {
 		session_id : ""
 		,job_id    : ""
 		,jobunit_id: ""
 		,facility_id: ""
+		,manager_ip : ""
 			
 		,/*
 		 * Set caption of grid
@@ -35,11 +34,21 @@ var fn = function(_view){
 		setCaption: function(){
 			var _ = this;
 			
-			_.grid.setCaption([
-				__.getLang("session_id"), ": ", _.session_id
-				,",&nbsp;"
-				,__.getLang("job_id"), ": " , _.job_id
-			].join(""));
+			if (_.manager_ip && _.manager_ip != "") {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+					,",&nbsp;"
+					,__.getLang("job_id"), ": " , _.job_id
+	                ,",&nbsp;",
+	                __.getLang("manager"), ": " , _.manager_ip
+				].join(""));
+			} else {
+				_.grid.setCaption([
+					__.getLang("session_id"), ": ", _.session_id
+					,",&nbsp;"
+					,__.getLang("job_id"), ": " , _.job_id
+				].join(""));
+			}
 		}
 		
 		,/*
@@ -50,9 +59,9 @@ var fn = function(_view){
 			,session_id = _view.__session_id
 			,job_id     = _view.__job_id
 			,jobunit_id = _view.__jobunit_id
+			,manager_ip = _view.__manager_ip
 			,grid       = _.grid
 			;
-			
 			// Check for update data
 			if((session_id !== _.session_id) 
 				|| (job_id !== _.job_id)
@@ -64,6 +73,7 @@ var fn = function(_view){
 			_.session_id = session_id;
 			_.job_id     = job_id;
 			_.jobunit_id = jobunit_id;
+			_.manager_ip = manager_ip;
 			_.setCaption();
 			
 			// Check to clear?
@@ -83,7 +93,12 @@ var fn = function(_view){
 			
 			$("#load_grid_jobmanagement_node_detail").show();
 			// Reload grid
-			grid.refreshData({sessionId: session_id, jobId: job_id, jobunitId: jobunit_id});
+			grid.refreshData({
+				sessionId: session_id,
+				jobId: job_id,
+				jobunitId: jobunit_id,
+				managerIpForSearch: manager_ip
+			});
 		}
 		
 		,/*
@@ -126,6 +141,11 @@ var fn = function(_view){
 						
 						post_data.jobunitId = _.jobunit_id;
 					}
+					if (_view.__manager_ip) {
+						_.manager_ip = _view.__manager_ip;
+						
+						post_data.managerIpForSearch = _.manager_ip;
+					}
 					
 					// Set some options for grid
 					$.extend(data_respond, {
@@ -402,6 +422,7 @@ var fn = function(_view){
 					,jobunitId  : _view.__jobunit_id
 					,jobId      : _view.__job_id
 					,facilityId : $.jgrid.htmlEncode(row_data.facilityId)
+					,managerIpForSearch:_.manager_ip
 				});
 				
 				// Set dialog title
@@ -435,6 +456,7 @@ var fn = function(_view){
 					,jobunitId  : _view.__jobunit_id
 					,jobId      : _view.__job_id
 					,facilityId : $.jgrid.htmlEncode(row_data.facilityId)
+					,managerIpForSearch:_.manager_ip
 				});
 				
 				// Set dialog title
