@@ -18,9 +18,7 @@ PURPOSE.  See the GNU General Public License for more details.
  * Create monitor scope
  */
 var fn = function(){
-	var __ = cm
-	,_pers = this
-	;
+	var __ = cm;
 	
 	 var view = $.extend({}, __._fnview_grid, {
 		 /*
@@ -35,9 +33,7 @@ var fn = function(){
 				,dataType: "json"
 				,type    : "get"
 				,success : function(data_respond){
-					var grid = _.grid
-					,pager   = grid.pager
-					;
+					var grid = _.grid;
 					
 					// Check validation of data_respond
 					if (__.checkJsonError(data_respond) !== true){
@@ -49,7 +45,11 @@ var fn = function(){
 						url: "get_schedule"
 					});
 					
-					grid.processData(data_respond);
+					if (data_respond.colNames.length == 13) {
+						grid.processData(data_respond, ['scheId', 'manager']);
+					} else {
+						grid.processData(data_respond, ['scheId']);
+					}
 					grid.controlSize();
 				}
 				,error   : __.loadDataError
