@@ -29,20 +29,23 @@ var fn = function (_view){
 	 var view = $.extend({}, __._fnview_tree_grid, {
 		load_flg    : false
 		,facility_id: ""
+		,manager_ip: ""
 		,
 		/*
 		 * Set caption of grid
 		 */
-		setCaption: function(path){
-			var _    = this
-			,caption = [__.getLang("scope"), ": " , path].join("")
-			;
-			
+		setCaption: function(path, managerIp){
+			var _    = this, caption;
+
+			if (managerIp == null || managerIp == "") {
+				caption = [__.getLang("scope"), ": " , path].join("");
+			} else {
+				caption = [__.getLang("scope"), "(", managerIp, "): " , path].join("");
+			}
 			// Check filter
 			if(!(_.filter_active)){
 				_.grid.setCaption(caption);
 			}
-			
 			// Store caption
 			_._caption = caption;
 		}
@@ -54,8 +57,9 @@ var fn = function (_view){
 			var _ = this
 			;
 			_.facility_id = node_data.facilityId;
+			_.manager_ip = node_data.managerIp;
 			// Set caption
-			_.setCaption(node_data.path);
+			_.setCaption(node_data.path, _.manager_ip);
 			
 			if (!(_.load_flg)) {
 				_.load_flg = true;
@@ -71,7 +75,8 @@ var fn = function (_view){
 			;
 			
 			_.grid.refreshData({
-				facilityId: _.facility_id
+				facilityId: _.facility_id,
+				managerIpForSearch: _.manager_ip
 			});
 		}
 		,/*
@@ -112,6 +117,7 @@ var fn = function (_view){
 							var post_data = grid.getGridParam("postData")
 								,facility_id
 								;
+							
 							if((facility_id = post_data.facilityId) === undefined){
 								facility_id = "";
 							}
@@ -120,7 +126,7 @@ var fn = function (_view){
 							}else{
 								setTimeout(function(){
 									_.reloadGrid();
-								}, 1);
+								}, 0);
 							}
 							// Set refresh data
 							_view.setRefresh();
@@ -269,11 +275,13 @@ var fn = function (_view){
 								});
 						}
 					});
-					
-					grid.processData(data_respond, ['monitorId', 'pluginId', 'facilityId', 'receiveTime']);
+					if (data_respond.colNames.length == 15) {
+						grid.processData(data_respond, ['monitorId', 'pluginId', 'facilityId', 'receiveTime', 'manager']);
+					} else {
+						grid.processData(data_respond, ['monitorId', 'pluginId', 'facilityId', 'receiveTime']);
+					}
 					grid.hideCol("cb"); // Hide check box
 					grid.controlSize();
-					
 					// Bind context menu for grid (right click)
 					grid.contextMenu(
 						"menu_rightclick"
@@ -453,6 +461,15 @@ var fn = function (_view){
 					,height : 400
 					,open   : function(){
 						$(this).siblings('div.ui-dialog-buttonpane:first').find("button:eq(1)").focus();
+						// FFの場合、下記のコードで「マネージャ」行を隠す
+						if((_.manager_ip == "" && $("tr[id=manager]")) || $("tr[id=manager]") == undefined) {
+							
+						} else {
+							setTimeout('$("tr[id=manager]").hide()', 0);
+						}
+					}
+					,beforeClose : function() {
+						_.filter.storeValues();
 					}
 					,buttons: [
 						{
@@ -506,6 +523,12 @@ var fn = function (_view){
 					,height : 400
 					,open   : function(){
 						$(this).siblings('div.ui-dialog-buttonpane:first').find("button:eq(0)").focus();
+						// FFの場合、下記のコードで「マネージャ」行を隠す
+						if((_.manager_ip == "" && $("tr[id=manager]")) || $("tr[id=manager]") == undefined) {
+							
+						} else {
+							setTimeout('$("tr[id=manager]").hide()', 0);
+						}
 					}
 					,buttons: [
 						{
@@ -563,7 +586,8 @@ var fn = function (_view){
 			
 			// Bind batch confirm
 			btns.children("#batchconfirm").click(function(){
-				_.batchconfirm.open();
+				// IEの場合、下記のコードで「マネージャ」行を隠す
+				_.batchconfirm.open(_.manager_ip);
 			});
 			
 			// Bind detail
@@ -583,7 +607,8 @@ var fn = function (_view){
 					_.filter_active = false;
 				}else{
 					// Open dialog which contain filter property grid
-					_.filter.open();
+					// IEの場合、下記のコードで「マネージャ」行を隠す
+					_.filter.open(_.manager_ip);
 				}
 			});
 			
@@ -613,7 +638,6 @@ var fn = function (_view){
 				var detail = _.detail
 				,row_data  = grid.getRowData(row_id)
 				;
-				
 				// Set post data
 				detail.setPostData({
 					monitorId   : $.jgrid.htmlEncode(row_data.monitorId)
@@ -621,6 +645,7 @@ var fn = function (_view){
 					,pluginId   : $.jgrid.htmlEncode(row_data.pluginId)
 					,facilityId : $.jgrid.htmlEncode(row_data.facilityId)
 					,receiveTime: row_data.receiveTime
+					,managerIpForSearch: row_data.manager != undefined ? row_data.manager: _.manager_ip
 				});
 				
 				// Open dialog
@@ -696,7 +721,6 @@ var fn = function (_view){
 					}
 					act_data[cnt_row] = post_row;
 				}
-				
 				// Confirmed action
 				grid.refreshData({
 					actionData: act_data
