@@ -19,7 +19,6 @@ PURPOSE.  See the GNU General Public License for more details.
  */
 var fn = function(_view){
 	var __ = cm
-	,_pers = this
 	;
 	
 	
@@ -116,7 +115,11 @@ var fn = function(_view){
 						}
 					});
 				
-					grid.processData(data_respond, ['facilityId']);
+					if (data_respond.colNames.length == 6) {
+						grid.processData(data_respond, ['facilityId', 'manager']);
+					} else {
+						grid.processData(data_respond, ['facilityId']);
+					}
 					grid.controlSize();
 					grid.hideCol("cb"); // Hide check box
 					grid.contextMenu(
@@ -234,7 +237,6 @@ var fn = function(_view){
 		* 再起動・モジュールアップデートリクエスト送信
 		*/
 		agentRestartAjax: function(post_data){
-			var _ = this;
 			$.ajax({
 				url      : "agent_restart"
 				,cache   : false
@@ -245,7 +247,7 @@ var fn = function(_view){
 					__.checkJsonError(data_respond,true);
 				}
 				,error   : __.loadDataError
-			})
+			});
 		}
 		,/*
 		*　選択した行の文字列を取得して、確認ダイアログを表示させる
@@ -253,9 +255,8 @@ var fn = function(_view){
 		agentAction: function(isUpdate){
 			var _   = this
 			,grid   = _.grid
-			,row_id
-			,col_name = "facilityId"
 			,list     = []
+			,managerIps=[]
 			,displist  = []
 			,selrows  = grid.getGridParam("selarrrow")
 			,cnt_row  = selrows.length
@@ -269,12 +270,15 @@ var fn = function(_view){
 			// 選択行の一覧をリストに配置
 			while(cnt_row--){
 				list[list.length] = grid.getRowData(selrows[cnt_row]).facilityId;
+				if (grid.getRowData(selrows[cnt_row]).manager) {
+					managerIps[managerIps.length] = grid.getRowData(selrows[cnt_row]).manager;
+				}
 				displist[displist.length] = $.jgrid.htmlEncode(grid.getRowData(selrows[cnt_row]).facilityName) + "("
 											+ grid.getRowData(selrows[cnt_row]).facilityId + ")";
 			}
 			
 			// 確認ダイアログの表示
-			_.openConfirmDlg(list,displist,isUpdate);
+			_.openConfirmDlg(list, managerIps, displist, isUpdate);
 		}
 		,/*
 		* 再起動ボタンを押したとき
@@ -296,34 +300,32 @@ var fn = function(_view){
 		* displist - 選択行一覧（ファシリティID、ファシリティ名）、ダイアログ表示用
 		* isUpdate - true：モジュールアップデート、false：再起動
 		*/ 
-		openConfirmDlg: function(list,displist,isUpdate){
+		openConfirmDlg: function(list, managerIps, displist, isUpdate){
 			var _   = this
-			,content1_str
 			,content2_str
 			,title_str = "confirmed"
 			,action_str;
 			
 			// 確認ダイアログ用の文字列キー
 			if(isUpdate){
-				content1_str = "agent_update_confirmed_1";
 				content2_str = "agent_update_confirmed_2";
-				action_str   = "update"
+				action_str   = "update";
 			}else{
-				content1_str = "agent_restart_confirmed_1";
 				content2_str = "agent_restart_confirmed_2";
-				action_str   = "restart"
+				action_str   = "restart";
 			}
 			
 			// 確認ダイアログ表示
 			__.openConfirmDlg(
 				{
-					content : __.getLang(content1_str)+displist.join()+__.getLang(content2_str)
+					content : displist.join()+__.getLang(content2_str)
 					,title : __.getLang(title_str)
 				},
 				// OKボタン押下時の処理、サーバにリクエストを送信
 				function(){
 					_.agentRestartAjax({
 						facilityId:list,
+						managerIp:managerIps,
 						action:action_str
 					});
 				}
