@@ -1,25 +1,28 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.necsoft.hinemos.webclient.accesscontrol.servlet;
 
 import java.io.IOException;
+import java.net.URLDecoder;
 import java.rmi.AccessException;
+import java.util.ArrayList;
+import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Locale;
-
 import javax.naming.CommunicationException;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -37,17 +40,16 @@ import com.necsoft.hinemos.webclient.lang.WebMessages;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
 import com.necsoft.hinemos.webclient.util.LogUtils;
 import com.necsoft.hinemos.webclient.util.LoginManager;
-import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * Hinemosマネージャに接続するクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class LoginAuthServlet extends CommonServlet {
     /**
-	 * 
+	 *
 	 */
     private static final long serialVersionUID = -8809478864238709832L;
 
@@ -56,75 +58,120 @@ public class LoginAuthServlet extends CommonServlet {
 
     /**
      * Handles the HTTP <code>GET</code> method.
-     * 
+     *
      * @param request
      *            servlet request
      * @param response
      *            servlet response
      */
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException {
 
-        // 中間変数を宣言
-        UserForm form = new UserForm();
-        LoginManager loginManager = new LoginManager();
-        UserBean userBean = new UserBean();
-        LoginAuthBusiness loginAuthBuss = new LoginAuthBusiness();
-        HttpSession session;
-
         logout(request);
-        session = request.getSession(true);
-        PopulateBeanUtils.populateBean(form, request);
-        if (!isValidRequestParam(form)) {
-            setUserBeanError(form, userBean, "message.accesscontrol.6",
-                    request.getLocale());
-            forwardJsp(request, response, userBean);
-            return null;
+        HttpSession session = request.getSession(true);
+
+        // ユーザID（複数、カンマ「,」で区切る）
+        String userName = request.getParameter("userName");
+        // パスワード（複数、カンマ「,」で区切る）
+        String password = request.getParameter("password");
+        // 接続先URL（複数、カンマ「,」で区切る）
+        String urlServer = request.getParameter("urlServer");
+        // 同じユーザＩＤ・パスワードを使用するフラグ
+        String useTheSameIDAndPwd = request.getParameter("useTheSameIDAndPwd");
+
+        String[] userNames = userName.split(AccessControlConstants.SPLIT_FOR_MULTI_LOGIN);
+        String[] passwords = password.split(AccessControlConstants.SPLIT_FOR_MULTI_LOGIN);
+        String[] urlServers = urlServer.split(AccessControlConstants.SPLIT_FOR_MULTI_LOGIN);
+
+        List<UserBean> userBeanList = new ArrayList<UserBean>();
+        LinkedHashMap<String, LoginManager> loginManagerMap = new LinkedHashMap<String, LoginManager>();
+        List<UserForm> userFormList = new ArrayList<UserForm>();
+        for (int i = 0; i < urlServers.length; i++) {
+            UserForm form = new UserForm();
+
+            // 同じユーザＩＤ・パスワードを使用するかどうかの判定。
+            if (useTheSameIDAndPwd != null && Boolean.parseBoolean(useTheSameIDAndPwd)) {
+                form.setUserName(URLDecoder.decode(userNames[0], request.getCharacterEncoding()));
+                form.setPassword(URLDecoder.decode(passwords[0], request.getCharacterEncoding()));
+            } else {
+                form.setUserName(URLDecoder.decode(userNames[i], request.getCharacterEncoding()));
+                form.setPassword(URLDecoder.decode(passwords[i], request.getCharacterEncoding()));
+            }
+            form.setUrlServer(URLDecoder.decode(urlServers[i], request.getCharacterEncoding()));
+            userFormList.add(form);
         }
-
         try {
-            loginAuthBuss.loginAuth(form, loginManager);
+            session.setAttribute(AccessControlConstants.THE_SAME_ID_AND_PWD_FLG, useTheSameIDAndPwd);
+            for (int i = 0; i < urlServers.length; i++) {
+                UserForm form = userFormList.get(i);
 
-            // Beanに設定
-            setUserBean(form, userBean);
+                UserBean userBean = new UserBean();
+                if (!isValidRequestParam(form)) {
+                    userBeanList.add(userBean);
+                    setUserBeanError(userFormList, userBeanList, "message.accesscontrol.6",
+                            request.getLocale());
+                    forwardJsp(request, response, userBeanList);
+                    return null;
+                }
+                LoginAuthBusiness loginAuthBuss = new LoginAuthBusiness();
+                LoginManager loginManager = new LoginManager();
 
-            // セッション保存
-            session.setAttribute(AccessControlConstants.USER_BEAN, userBean);
-            session.setAttribute(AccessControlConstants.LOGIN_MANAGER, loginManager);
+                // Beanに設定
+                setUserBean(form, userBean);
+                userBeanList.add(userBean);
+
+                loginAuthBuss.loginAuth(form, loginManager);
+                loginManagerMap.put(userBean.getManagerIp(), loginManager);
+            }
 
             // Set httpOnly to cookie
             response.setHeader("SET-COOKIE", "JSESSIONID=" + session.getId()
                     + "; Path=" + request.getContextPath() + "; HttpOnly");
             response.sendRedirect(request.getContextPath() + "/home");
-            return null;
+
+            // セッション保存
+            session.setAttribute(AccessControlConstants.USER_BEAN, userBeanList);
+            session.setAttribute(AccessControlConstants.LOGIN_MANAGER,
+                    loginManagerMap);
 
         } catch (CommunicationException ex) {
             // サーバへの接続例外が発生する場合
-            setUserBeanError(form, userBean, "message.accesscontrol.6",
+            setUserBeanError(userFormList, userBeanList, "message.accesscontrol.6",
                     request.getLocale());
             logUtils.error("message.accesscontrol.6", ex.getCause());
+            // Jspにフォワードする
+            forwardJsp(request, response, userBeanList);
 
         } catch (AccessException ex) {
             // アクセスの例外発生する場合
-            setUserBeanError(form, userBean, "message.accesscontrol.6",
+            setUserBeanError(userFormList, userBeanList, "message.accesscontrol.6",
                     request.getLocale());
             logUtils.error("message.accesscontrol.6", ex.getCause());
+            // Jspにフォワードする
+            forwardJsp(request, response, userBeanList);
 
         } catch (Exception ex) {
             // 予期せぬ例外発生する場合
-            setUserBeanError(form, userBean, "message.accesscontrol.6",
+            setUserBeanError(userFormList, userBeanList, "message.accesscontrol.6",
                     request.getLocale());
             logUtils.error("message.accesscontrol.21", ex.getCause());
+            // Jspにフォワードする
+            forwardJsp(request, response, userBeanList);
+        } catch (Error error) {
+            // 予期せぬ例外発生する場合
+            setUserBeanError(userFormList, userBeanList, "message.accesscontrol.6",
+                    request.getLocale());
+            logUtils.error("message.accesscontrol.21", error.getCause());
+            // Jspにフォワードする
+            forwardJsp(request, response, userBeanList);
         }
-
-        // Jspにフォワードする
-        forwardJsp(request, response, userBean);
         return null;
     }
 
     /**
      * This method used for logout
-     * 
+     *
      * @author hieunt
      * @param request
      *            : HttpServletRequest
@@ -133,18 +180,18 @@ public class LoginAuthServlet extends CommonServlet {
     private void logout(HttpServletRequest request) {
         HttpSession session = request.getSession(true);
         // セッションにuserBeanの存在チェック
-        UserBean userBean = (UserBean) session
+        Object userBean = session
                 .getAttribute(AccessControlConstants.USER_BEAN);
         if (userBean != null) {
             session.removeAttribute(AccessControlConstants.USER_BEAN);
         }
-        
+
         LoginSessionManager.processLogout(session);
     }
 
     /**
      * This method used for check ValidRequestParam
-     * 
+     *
      * @author hieunt
      * @param form
      *            : UserForm
@@ -190,7 +237,7 @@ public class LoginAuthServlet extends CommonServlet {
 
     /**
      * This method used for forward Jsp page
-     * 
+     *
      * @author hieunt
      * @param request
      *            : HttpServletRequest
@@ -203,10 +250,10 @@ public class LoginAuthServlet extends CommonServlet {
      * @return boolean
      */
     private void forwardJsp(HttpServletRequest request,
-            HttpServletResponse response, UserBean userBean)
+            HttpServletResponse response, List<UserBean> userBeanList)
             throws ServletException, IOException {
         request.getSession(true).setAttribute(AccessControlConstants.USER_BEAN,
-                userBean);
+                userBeanList);
 
         // login.jspにフォワードする
         getServletContext().getRequestDispatcher(
@@ -214,11 +261,19 @@ public class LoginAuthServlet extends CommonServlet {
                 response);
     }
 
-    private void setUserBeanError(UserForm form, UserBean userBean,
+    private void setUserBeanError(List<UserForm> formList, List<UserBean> userBeanList,
             String errorCode, Locale locale) {
-        userBean.setUserName(form.getUserName());
-        userBean.setUrlServer(form.getUrlServer());
-        userBean.setErrMessage(WebMessages.getString(errorCode, locale));
+        userBeanList.get(0).setErrMessage(WebMessages.getString(errorCode, locale));
+        for (int i = 0; i < formList.size(); i++) {
+            if (i > userBeanList.size() - 1) {
+                UserBean userBean = new UserBean();
+                setUserBean(formList.get(i), userBean);
+                userBeanList.add(userBean);
+            } else {
+                userBeanList.get(i).setUserName(formList.get(i).getUserName());
+                userBeanList.get(i).setUrlServer(formList.get(i).getUrlServer());
+            }
+        }
     }
 
     private void setUserBean(UserForm form, UserBean userBean) {
