@@ -1,23 +1,26 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.accesscontrol.servlet;
 
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
 
+import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -27,15 +30,16 @@ import org.apache.log4j.Logger;
 
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.accesscontrol.bean.UserBean;
+import com.necsoft.hinemos.webclient.accesscontrol.util.UrlListFileOperator;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
 
 /**
  * 初期表示ログイン画面のサブレットを定義するクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
-public class LoginServlet extends HttpServlet {
+public class LoginServlet extends HttpServlet implements AccessControlConstants {
 
     private static final long serialVersionUID = 8524643650658167194L;
 
@@ -43,12 +47,13 @@ public class LoginServlet extends HttpServlet {
 
     /**
      * Handles the HTTP <code>GET</code> method.
-     * 
+     *
      * @param request
      *            servlet request
      * @param response
      *            servlet response
      */
+    @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response) {
         // Initialize environment
         try {
@@ -61,14 +66,29 @@ public class LoginServlet extends HttpServlet {
         String localAddr = request.getLocalAddr();
         HttpSession session = request.getSession(true);
 
-        // セッションからuserBeanを取得
-        UserBean userBean = (UserBean) session.getAttribute(AccessControlConstants.USER_BEAN);
+        ServletContext application = request.getSession().getServletContext();
+        @SuppressWarnings("unchecked")
+        // applicationからURLリストを取得
+        List<String> urlList = (List<String>)application.getAttribute(URL_LIST);
+        if (urlList == null) {
+            urlList = UrlListFileOperator.getUrlList((String)application.getAttribute(URL_LIST_FILE_PATH));
+            application.setAttribute(URL_LIST, urlList);
+        }
 
-        if (userBean == null) {
-            userBean = setDefaultUserBean(localAddr);
+        // セッションからuserBeanを取得
+        @SuppressWarnings("unchecked")
+        List<UserBean> userBeanList = (List<UserBean>) session.getAttribute(USER_BEAN);
+
+        if (userBeanList == null) {
+            userBeanList = new ArrayList<UserBean>();
+            UserBean userBean = setDefaultUserBean(localAddr);
+            if (urlList.size() > 0) {
+                userBean.setUrlServer(urlList.get(0));
+            }
+            userBeanList.add(userBean);
 
             // セッションにuserBeanを登録
-            session.setAttribute(AccessControlConstants.USER_BEAN, userBean);
+            session.setAttribute(USER_BEAN, userBeanList);
         }
 
         // login.jspにフォワードする
@@ -80,14 +100,16 @@ public class LoginServlet extends HttpServlet {
         }
     }
 
+
     /**
      * Handles the HTTP <code>POST</code> method.
-     * 
+     *
      * @param request
      *            servlet request
      * @param response
      *            servlet response
      */
+    @Override
     public void doPost(HttpServletRequest request, HttpServletResponse response) {
         doGet(request, response);
     }
@@ -101,10 +123,10 @@ public class LoginServlet extends HttpServlet {
     public UserBean setDefaultUserBean(String localAddress) {
         // 非存在の場合、
         UserBean userBean = new UserBean();
-        userBean.setUserName(AccessControlConstants.HINEMOS_USER_DEFAULT);
-        userBean.setUrlServer(AccessControlConstants.HINEMOS_HTTP_PROTOCAL_DEFAULT
+        userBean.setUserName(HINEMOS_USER_DEFAULT);
+        userBean.setUrlServer(HINEMOS_HTTP_PROTOCAL_DEFAULT
                 + localAddress
-                + AccessControlConstants.HINEMOS_HTTP_PORT_DEFAULT);
+                + HINEMOS_HTTP_PORT_DEFAULT);
         return userBean;
     }
 }
