@@ -19,7 +19,6 @@ package com.necsoft.hinemos.webclient.accesscontrol.util;
 import javax.servlet.http.HttpSession;
 
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
-import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * ログインに関するセッションを管理するクラス
@@ -50,7 +49,7 @@ public class LoginSessionManager {
 
     public static void processLogout(HttpSession session, boolean invalidSession) {
         // セッションにloginManagerの存在チェック
-        LoginManager loginManager = (LoginManager) session
+        Object loginManager = session
                 .getAttribute(AccessControlConstants.LOGIN_MANAGER);
         if (loginManager != null) {
             session.removeAttribute(AccessControlConstants.LOGIN_MANAGER);
