@@ -44,11 +44,11 @@ public class FacilityTree {
      * 
      * @return スコープツリー構造
      */
-    public FacilityTreeItem getTreeItem(EndpointManager endpointManager) {
+    public FacilityTreeItem getTreeItem(EndpointManager endpointManager, String managerIp) {
         FacilityTreeItem item = null;
 
         // 存在しない場合はキャッシュ再交信再取得
-        refleshCache(endpointManager);
+        refleshCache(endpointManager, managerIp);
         
         // 要素を取得
         item = FacilityTreeItemUtil.deepCopy(m_facilityTreeCache, null);
@@ -79,11 +79,11 @@ public class FacilityTree {
     /**
      * キャッシュのリフレッシュ
      */
-    public static void refleshCache(EndpointManager endpointManager) {
+    private static void refleshCache(EndpointManager endpointManager, String managerIp) {
         // 再登録
         FacilityTreeItem item = null;
         try {
-            item = RepositoryEndpointWrapper.getFacilityTree(endpointManager);
+            item = RepositoryEndpointWrapper.getFacilityTree(endpointManager, managerIp);
 
             if (item != null) {
                 m_facilityTreeCache = item;
