@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.common;
@@ -44,49 +44,22 @@ import com.necsoft.hinemos.webclient.util.SortOrderUtil;
 
 /**
  * HTMLに関する処理を定義する共有クラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class DataProcess {
 
-    /**
-     * 文字列をHEXに交換する
-     * 
-     * @param 文字列
-     * @return HEX文字列
-     */
-    public static final String stringToHex(String strInput) {
-        if ((strInput == null) || (strInput.equals("")))
-            return "";
-
-        int length = strInput.length();
-        StringBuffer result = new StringBuffer();
-        for (int pos = 0; pos < length; pos++) {
-            int this_char = (int) strInput.charAt(pos);
-            for (int digit = 0; digit < 4; digit++) {
-                int this_digit = this_char & 0xf000;
-                this_char = this_char << 4;
-                this_digit = (this_digit >> 12);
-                if (this_digit >= 10)
-                    result.append((char) (this_digit + 87));
-                else
-                    result.append((char) (this_digit + 48));
-            }
-        }
-        return result.toString();
-    }
-
-    public static final Map<String, Object> getRowFromProperty(Property property) {
+    private static final Map<String, Object> getRowFromProperty(Property property) {
         return getRowFromProperty(property, JsConstant.TREEGRID_ROOT_LEVEL);
     }
 
-    public static final Map<String, Object> getRowFromProperty(
+    private static final Map<String, Object> getRowFromProperty(
             Property property, int level) {
         return getRowFromProperty(property, level, false);
     }
 
-    public static final Map<String, Object> getRowFromProperty(
+    private static final Map<String, Object> getRowFromProperty(
             Property property, int level, boolean valueWithChild) {
         Map<String, Object> data = new HashMap<String, Object>();
         Property proParent;
@@ -115,7 +88,7 @@ public class DataProcess {
             if (property.getChildren().length < 1) {
                 isLeaf = true;
             }
-            
+
             StringBuffer buf = new StringBuffer();
 
             // Set value properly
@@ -171,7 +144,7 @@ public class DataProcess {
                 buf.append(id);
                 buf.append("' class='");
 
-                String editor = property.getEditor().toString();
+                String editor = property.getEditor();
 
                 // Check type value of input text
                 if (editor.equals(PropertyClass.DATETIME_EDITOR)) {
@@ -188,14 +161,14 @@ public class DataProcess {
                         buf.append("' readonly='readonly");
                     }
                     buf.append("' value='");
-                    
+
                     if (editor.equals(PropertyConstant.EDITOR_NUM)) {
                         buf.append("' min='");
                         buf.append(property.getLowerBound());
                         buf.append("' max='");
                         buf.append(property.getUpperBound());
                     }
-                    
+
                     buf.append(propValue);
                 }
 
@@ -204,7 +177,7 @@ public class DataProcess {
                 if (editor.equals(PropertyClass.JOBID_EDITOR)) {
                     buf.append("<button class='");
                     buf.append(CssClass.GRID_INNER_BUTTON_OPEN_TREE_JOB);
-                    buf.append("'/>");
+                    buf.append("'/><input type='hidden' id='jobManager'/>");
                 }
             }
 
@@ -231,7 +204,7 @@ public class DataProcess {
 
     /**
      * This method used for convert header of grid to JSON data.
-     * 
+     *
      * @author hungcv
      * @version 2.0
      * @since 2012/07/11
@@ -248,15 +221,15 @@ public class DataProcess {
      * @return GridHeaderJson
      */
     public static final GridHeaderJson doConvertTableDefineToJson(
-            ArrayList<TableColumnInfoJs> tblDefine, boolean recordsFlag, Locale locale, 
+            ArrayList<TableColumnInfoJs> tblDefine, boolean recordsFlag, Locale locale,
             int row_num, int column_index, int sort_order) {
         // Create JSON
         return doConvertTableDefineToJson(tblDefine, recordsFlag, locale, row_num
                 ,column_index, sort_order, false);
     }
-    
+
     public static final GridHeaderJson doConvertTableDefineToJson(
-            ArrayList<TableColumnInfoJs> tblDefine, boolean recordsFlag, Locale locale, 
+            ArrayList<TableColumnInfoJs> tblDefine, boolean recordsFlag, Locale locale,
             int row_num, int column_index, int sort_order, boolean indexlikeName) {
         // Create JSON
         GridHeaderJson result = new GridHeaderJson();
@@ -268,20 +241,22 @@ public class DataProcess {
         if (indexlikeName) {
             result.setSortname(tblDefine.get(column_index).getModelName());
         }
-        
+
         result.setSortorder(SortOrderUtil.getJsString(sort_order));
         if (recordsFlag) {
             result.setRecordtext(WebMessages.getString("records",
                     new Object[] { "{1}" }, locale));
             result.setEmptyrecords(WebMessages.getString("records",
                     new Object[] { "0" }, locale));
+            result.setExceedrecord(WebMessages.getString("exceed.records",
+                    new Object[] { "{1}" }, locale));
         }
         return result;
     }
 
     /**
      * This method used for convert data of grid to JSON data.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2012/07/11
@@ -292,7 +267,7 @@ public class DataProcess {
      * @return GridDataJson
      */
     public static final GridDataJson doConvertTableContentToJson(
-            ArrayList<ArrayList<Object>> listInfoData) {
+            List<ArrayList<Object>> listInfoData) {
         // Create JSON
         GridDataJson result = new GridDataJson();
 
@@ -305,10 +280,10 @@ public class DataProcess {
         result.setRecords(listInfoData.size());
         return result;
     }
-    
+
     /**
      * This method used for convert data of grid to JSON data.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2012/07/11
@@ -360,7 +335,7 @@ public class DataProcess {
                     type = JsConstant.GRID_FMATTER_CONFIRM_TYPE;
                     value = Integer.parseInt(value.toString());
                     break;
-                    
+
                 default:        //Others
                     type = JsConstant.PROPERTY_TYPE_TEXT;
                     value = StringEscapeUtils.escapeHtml4(value.toString());
@@ -388,7 +363,7 @@ public class DataProcess {
 
     /**
      * This method used for convert data row of grid to TreeGridJson data.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2011/12/14
@@ -420,10 +395,10 @@ public class DataProcess {
         }
         return result;
     }
-    
+
     /**
      * This method used for sort data of grid.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2011/12/14
@@ -435,27 +410,21 @@ public class DataProcess {
      *            : int
      * @param sortOrder
      *            : int
-     * @param iMaxColValue
-     *            : int
      * @return void
      */
-    public static final void sortData(GridForm form, ArrayList<?> listInfoData,
-            int sortColumnIndex, int sortOrder, int iMaxColValue) {
-
-        if (form.getSidx() != null && !("").equals(form.getSidx().trim())) {
-            if (Integer.valueOf(form.getSidx()) < iMaxColValue) {
-                sortColumnIndex = Integer.valueOf(form.getSidx());
-            }
+    public static List<ArrayList<Object>> doSortListDataInfo(GridForm form, List<ArrayList<Object>> listInfoData, int sortColumnIndex, int sortOrder) {
+        if (form.getSidx() != null && !form.getSidx().trim().equals("")) {
+            sortColumnIndex = Integer.valueOf(form.getSidx());
         }
-        if (form.getSord() != null && !("").equals(form.getSord().trim())) {
+        if (form.getSord() != null && !form.getSord().trim().equals("")) {
             sortOrder = SortOrderUtil.getSerInt(form.getSord());
         }
-
         // データをソート
         Collections.sort(listInfoData, new CommonTableViewerSorter(
                 sortColumnIndex, -1, sortOrder));
+        return listInfoData.subList(0, form.getMaxRowNum() > listInfoData.size() ? listInfoData.size() : form.getMaxRowNum());
     }
-    
+
     public static final int getViewerSchedule(Date date, Date today) {
         // 中間変数を宣言
         SimpleDateFormat m_formatter = new SimpleDateFormat(
@@ -516,7 +485,7 @@ public class DataProcess {
 
         // Get value of expanded
         boolean expanded = false;
-        
+
         //expand for "Basic Information", "Service" and "Device"
         if(id == NodeConstant.BASIC_INFORMATION || id == NodeConstant.SERVICE || id == NodeConstant.DEVICE)
         {
@@ -579,7 +548,7 @@ public class DataProcess {
 
     /**
      * This method is used for convert data row of grid to TreeGridJson data.
-     * 
+     *
      * @author thundh
      * @since 2013/01/16
      * @param propertyInfo
