@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.composite;
@@ -22,7 +22,7 @@ import java.util.Comparator;
 
 /**
  * CommonTableViewerSorterクラス用のComparatorクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -38,7 +38,7 @@ public class CommonTableViewerSorter implements Comparator<Object> {
 
     /**
      * コンストラクタ
-     * 
+     *
      * @param column
      *            ソート対象カラムインデックス
      * @since 1.0.0
@@ -49,7 +49,7 @@ public class CommonTableViewerSorter implements Comparator<Object> {
 
     /**
      * コンストラクタ
-     * 
+     *
      * @param column
      *            ソート対象カラムインデックス
      * @param columnIndex
@@ -60,7 +60,7 @@ public class CommonTableViewerSorter implements Comparator<Object> {
 
     /**
      * コンストラクタ
-     * 
+     *
      * @param column
      *            ソート対象カラムインデックス
      * @param order
@@ -80,13 +80,14 @@ public class CommonTableViewerSorter implements Comparator<Object> {
 
     /**
      * 比較処理
-     * 
+     *
      * @param viewer
      * @param e1
      * @param e2
      * @return 比較結果。superクラスの結果をソートオーダーにより反転する
      * @since 1.0.0
      */
+    @Override
     public int compare(Object e1, Object e2) {
         if (e1 == null || e2 == null) {
             return 0;
@@ -107,24 +108,32 @@ public class CommonTableViewerSorter implements Comparator<Object> {
             } else if ((object1 != null) && (object2 == null)) {
                 rtn = 1;
             } else {
-                if (/*
-                     * object1 != null && object2 != null &&
-                     */object1.getClass() == Date.class
+                if (object1.getClass() == Date.class
                         && object2.getClass() == Date.class) {
                     rtn = ((Date) object1).compareTo((Date) object2);
 
-                } else if (/*
-                            * object1 != null && object2 != null &&
-                            */object1.getClass() == Integer.class
+                } else if (object1.getClass() == Integer.class
                         && object2.getClass() == Integer.class) {
                     // Intergerの場合には、compareではなく値の大小を比較する。
                     // 2と10だと2を前にする。
                     rtn = ((Integer) object1).intValue()
                             - ((Integer) object2).intValue();
+//                } else if (object1.toString().matches(FacilityConstant.IP_ADDRESS_PARTERN)) {
+//                    String ip1 = object1.toString();
+//                    String ip2 = object2.toString();
+//                    // IPアドレスの大小を比較する
+//                    String[] ip1Numbers = ip1.split("\\.");
+//                    String[] ip2Numbers = ip2.split("\\.");
+//                    for (int i = 0; i < ip1Numbers.length; i++) {
+//                        int ip1Num = Integer.parseInt(ip1Numbers[i]);
+//                        int ip2Num = Integer.parseInt(ip2Numbers[i]);
+//                        rtn = ip1Num - ip2Num;
+//                        if (rtn != 0) {
+//                            break;
+//                        }
+//                    }
                 } else {
-                    /* if (object1 != null && object2 != null) { */
                     rtn = (object1.toString()).compareTo(object2.toString());
-                    /* } */
                 }
             }
 
@@ -143,25 +152,19 @@ public class CommonTableViewerSorter implements Comparator<Object> {
                     rtn = 1;
                 } else {
                     // 上と同じ
-                    if (/*
-                         * object1 != null && object2 != null &&
-                         */object1.getClass() == Date.class
+                    if (object1.getClass() == Date.class
                             && object2.getClass() == Date.class) {
                         rtn = ((Date) object1).compareTo((Date) object2);
 
-                    } else if /*(object1 != null && object2 != null) {
-                        if*/ (object1.getClass() == Integer.class
+                    } else if (object1.getClass() == Integer.class
                                 && object2.getClass() == Integer.class) {
                             // Intergerの場合には、compareではなく値の大小を比較する。
                             // 2と10だと2を前にする。
                             rtn = ((Integer) object1).intValue()
                                     - ((Integer) object2).intValue();
-                        /*}*/
                     } else {
-                        /* if (object1 != null && object2 != null) { */
                         rtn = (object1.toString())
                                 .compareTo(object2.toString());
-                        /* } */
                     }
                 }
 
@@ -178,7 +181,7 @@ public class CommonTableViewerSorter implements Comparator<Object> {
 
     /**
      * ソート対象カラムインデックス取得
-     * 
+     *
      * @return カラムインデックス
      * @since 1.0.0
      */
