@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.form;
@@ -21,6 +21,15 @@ public class GridForm {
 
     private String sord;
 
+    /**
+     * マネージャIPアドレス<br>
+     * （左ペインのノードを選択する時検索用）
+     */
+    private String managerIpForSearch;
+
+    /** 最大表示件数 */
+    private int maxRowNum;
+
     /**
      * @return the sidx
      */
@@ -51,4 +60,20 @@ public class GridForm {
         this.sord = sord;
     }
 
+    public String getManagerIpForSearch() {
+        return managerIpForSearch;
+    }
+
+    public void setManagerIpForSearch(String managerIpForSearch) {
+        this.managerIpForSearch = managerIpForSearch;
+    }
+
+    public int getMaxRowNum() {
+        return maxRowNum;
+    }
+
+    public void setMaxRowNum(int maxRowNum) {
+        this.maxRowNum = maxRowNum;
+    }
+
 }
