@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.action;
@@ -25,7 +25,7 @@ import com.necsoft.hinemos.webclient.lang.WebMessages;
 
 /**
  * ジョブ[履歴]ビューのテーブル定義を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -61,7 +61,9 @@ public class GetHistoryTableDefine {
     public static final int TRIGGER_TYPE = 13;
     /** 実行契機情報 */
     public static final int TRIGGER_INFO = 14;
-    
+    /** マネージャ */
+    public static final int MANAGER = 15;
+
     /** 初期表示時ソートカラム */
     public static final int SORT_COLUMN_INDEX = SESSION_ID;
     /** 初期表示時ソートオーダー (昇順=1, 降順=-1) */
@@ -69,10 +71,10 @@ public class GetHistoryTableDefine {
 
     /**
      * ジョブ[履歴]ビューのテーブル定義を取得する
-     * 
+     *
      * @return テーブル定義情報
      */
-    public static ArrayList<TableColumnInfoJs> get(Locale locale) {
+    public static ArrayList<TableColumnInfoJs> get(Locale locale, boolean isManagerIpRequired) {
         /** テーブル定義配列*/
         ArrayList<TableColumnInfoJs> tableDefine = new ArrayList<TableColumnInfoJs>();
 
@@ -118,15 +120,15 @@ public class GetHistoryTableDefine {
                 TableColumnInfoJs.FACILITY, 150, SWT.LEFT,
                 JobMappingUtil.getHistoryName(SCOPE)));
         tableDefine.add(SCHEDULED_START_TIME, new TableColumnInfoJs(
-                WebMessages.getString("scheduled.start.time", locale), 
+                WebMessages.getString("scheduled.start.time", locale),
                 TableColumnInfoJs.NONE, 140, SWT.LEFT,
                 JobMappingUtil.getHistoryName(SCHEDULED_START_TIME)));
         tableDefine.add(START_RERUN_TIME, new TableColumnInfoJs(
-                WebMessages.getString("start.rerun.time", locale), 
+                WebMessages.getString("start.rerun.time", locale),
                 TableColumnInfoJs.NONE, 140, SWT.LEFT,
                 JobMappingUtil.getHistoryName(START_RERUN_TIME)));
         tableDefine.add(END_SUSPEND_TIME, new TableColumnInfoJs(
-                WebMessages.getString("end.suspend.time", locale), 
+                WebMessages.getString("end.suspend.time", locale),
                 TableColumnInfoJs.NONE, 140, SWT.LEFT,
                 JobMappingUtil.getHistoryName(END_SUSPEND_TIME)));
         tableDefine.add(TRIGGER_TYPE, new TableColumnInfoJs(
@@ -137,6 +139,12 @@ public class GetHistoryTableDefine {
                 WebMessages.getString("trigger.info", locale),
                 TableColumnInfoJs.NONE, 140, SWT.LEFT,
                 JobMappingUtil.getHistoryName(TRIGGER_INFO)));
+        if (isManagerIpRequired) {
+            tableDefine.add(MANAGER, new TableColumnInfoJs(
+                    WebMessages.getString("manager", locale),
+                    TableColumnInfoJs.NONE, 150, SWT.LEFT,
+                    JobMappingUtil.getHistoryName(MANAGER)));
+        }
 
         return tableDefine;
     }
