@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.action;
@@ -25,7 +25,7 @@ import com.necsoft.hinemos.webclient.lang.WebMessages;
 
 /**
  * ジョブ[スケジュール]ビューのテーブル定義を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -55,18 +55,20 @@ public class GetScheduleTableDefine {
     public static final int UPDATE_USER = 10;
     /** 最終更新日時 */
     public static final int UPDATE_TIME = 11;
+    /** マネージャ */
+    public static final int MANAGER = 12;
 
     /** 初期表示時ソートカラム */
     public static final int SORT_COLUMN_INDEX = SCHE_ID;
     /** 初期表示時ソートオーダー (昇順=1, 降順=-1) */
     public static final int SORT_ORDER = 1;
-    
+
     /**
      * ジョブ[スケジュール]ビューのテーブル定義を取得する
-     * 
-     * @return テーブル定義情報 
+     *
+     * @return テーブル定義情報
      */
-    public static ArrayList<TableColumnInfoJs> get(Locale locale) {
+    public static ArrayList<TableColumnInfoJs> get(Locale locale, boolean isManagerIpRequired) {
         /** テーブル定義配列*/
         ArrayList<TableColumnInfoJs> tableDefine = new ArrayList<TableColumnInfoJs>();
 
@@ -120,6 +122,12 @@ public class GetScheduleTableDefine {
                 WebMessages.getString("update.time", locale),
                 TableColumnInfoJs.NONE, 140, SWT.LEFT,
                 JobMappingUtil.getJobScheduleName(UPDATE_TIME)));
+        if (isManagerIpRequired) {
+            tableDefine.add(MANAGER, new TableColumnInfoJs(
+                    WebMessages.getString("manager", locale),
+                    TableColumnInfoJs.NONE, 150, SWT.LEFT,
+                    JobMappingUtil.getJobScheduleName(MANAGER)));
+        }
 
         return tableDefine;
     }
