@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.bean;
@@ -24,12 +24,12 @@ import com.necsoft.hinemos.webclient.bean.TreeInfo;
 
 /**
  * ファシリティ情報定義するクラス
- * 
+ *
  **/
 public class JobTreeBean extends TreeInfo implements Serializable {
 
     /**
-	 * 
+	 *
 	 */
     private static final long serialVersionUID = -4354544925806741380L;
 
@@ -41,6 +41,9 @@ public class JobTreeBean extends TreeInfo implements Serializable {
 
     private Map<String, Object> jobData;
 
+    /** マネージャのIPアドレス */
+    private String managerIp = "";
+
     private ArrayList<JobTreeBean> children;
 
     public JobTreeBean() {
@@ -119,4 +122,12 @@ public class JobTreeBean extends TreeInfo implements Serializable {
         this.children = children;
     }
 
+    public String getManagerIp() {
+        return managerIp;
+    }
+
+    public void setManagerIp(String managerIp) {
+        this.managerIp = managerIp;
+    }
+
 }
