@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.business;
@@ -31,7 +31,6 @@ import com.clustercontrol.ws.jobmanagement.JobInfoNotFound_Exception;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
-import com.necsoft.hinemos.webclient.jobmanagement.JobManagementConstants;
 import com.necsoft.hinemos.webclient.jobmanagement.action.GetForwardFileTableDefine;
 import com.necsoft.hinemos.webclient.jobmanagement.form.ForwardFileForm;
 import com.necsoft.hinemos.webclient.jobmanagement.util.ConvertListUtil;
@@ -40,7 +39,7 @@ import com.necsoft.hinemos.webclient.util.EndpointManager;
 
 /**
  * This class used for get Forward File list
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -48,7 +47,7 @@ public class GetForwardFileBusiness {
 
     /**
      * Get Forward File list
-     * 
+     *
      * @param form
      *            : ForwardFileForm
      * @return ArrayList<JobForwardFile>
@@ -56,7 +55,7 @@ public class GetForwardFileBusiness {
      */
     public ArrayList<ArrayList<Object>> getForwardFile(ForwardFileForm form,
         EndpointManager endpointManager) throws HinemosWebException {
-        
+
         List<JobForwardFile> listItem = null;
 
         try {
@@ -81,16 +80,15 @@ public class GetForwardFileBusiness {
             // Hinemosマネージャより応答がありませんでした。ログアウトします。
             throw new HinemosWebException("message.force.disconnect");
         }
-        
+
         ArrayList<ArrayList<Object>> list = ConvertListUtil
             .jobForwardFileListToArrayList(listItem);
 
         ConvertListUtil.sanitizeForwardFileList(list);
-        
-        DataProcess.sortData(form, list,
+
+        DataProcess.doSortListDataInfo(form, list,
                 GetForwardFileTableDefine.SORT_COLUMN_INDEX,
-                GetForwardFileTableDefine.SORT_ORDER,
-                JobManagementConstants.FORWARD_FILE_HEADER_NUM);
+                GetForwardFileTableDefine.SORT_ORDER);
 
         return list;
     }
