@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.business;
@@ -49,27 +49,27 @@ import com.necsoft.hinemos.webclient.util.EndpointManager;
 
 /**
  * This class used for get Job tree
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
 public class GetJobTreeBusiness {
     /** パスセパレータ */
     private static final String SEPARATOR = ">";
-    
+
     /**
      * Get job list
      * @return JobTreeJson
      * @throws HinemosWebException
      */
-    public JobTreeItem getJobTree(EndpointManager endpointManager)
+    public JobTreeItem getJobTree(EndpointManager endpointManager, String managerIp)
             throws HinemosWebException {
 
         // JobTree を取得
         JobTreeItem jobTreeItem = null;
-        
+
         try {
-            jobTreeItem = JobEndpointWrapper.getJobTree(false, endpointManager);
+            jobTreeItem = JobEndpointWrapper.getJobTree(false, endpointManager, managerIp);
         } catch (InvalidRole_Exception e) {
             // アクセス権なしの場合
             throw new HinemosWebAccessException("exception.data.access");
@@ -97,13 +97,15 @@ public class GetJobTreeBusiness {
         return jobTreeItem;
     }
 
-    public JobTreeJson doConvertToJson(JobTreeItem jobTreeItem, String userName) {
+    public JobTreeJson doConvertToJson(JobTreeJson jobTreeJs, JobTreeItem jobTreeItem, String userName, String managerIp) {
         // Create data JSON
         List<JobTreeItem> treeItems = jobTreeItem.getChildren();
-        JobTreeJson jobTreeJs = new JobTreeJson();
+        if (jobTreeJs == null) {
+            jobTreeJs = new JobTreeJson();
+        }
         for (int cnt = 0; cnt < treeItems.size(); cnt++) {
             jobTreeJs
-                    .addJobTree(treeItem2TreeBean(treeItems.get(cnt), userName));
+                    .addJobTree(treeItem2TreeBean(treeItems.get(cnt), userName, managerIp));
         }
 
         return jobTreeJs;
@@ -111,13 +113,13 @@ public class GetJobTreeBusiness {
 
     /**
      * Convert JobTreeItem to FacilityTreeBean
-     * 
+     *
      * @param treeItem
      * @param path
      * @param key
      * @return JobTreeBean
      */
-    private JobTreeBean treeItem2TreeBean(JobTreeItem treeItem, String userName) {
+    private JobTreeBean treeItem2TreeBean(JobTreeItem treeItem, String userName, String managerIp) {
         JobTreeBean treeBean = new JobTreeBean();
         JobInfo jobInfo = treeItem.getData();
 
@@ -143,6 +145,7 @@ public class GetJobTreeBusiness {
         treeBean.setJobId(jobId);
         treeBean.setPath(StringEscapeUtils.escapeHtml4(getPath(treeItem)));
         treeBean.setJobunitId(jobInfo.getJobunitId());
+        treeBean.setManagerIp(managerIp);
 
         // Set children of node
         if (type == JobConstant.TYPE_FILEJOB) {
@@ -170,7 +173,7 @@ public class GetJobTreeBusiness {
             // 子ノードリストを取得
             for (int cnt = 0; cnt < treeItems.size(); cnt++) {
                 treeBean.addChildren(treeItem2TreeBean(treeItems.get(cnt),
-                        userName));
+                        userName, managerIp));
             }
         }
 
@@ -193,7 +196,7 @@ public class GetJobTreeBusiness {
             jobData.put(JobMappingUtil.getJobName(GetJobTableDefine.FACILITY_ID),
                     StringEscapeUtils.escapeHtml4(exec.getFacilityID()));
             jobData.put(JobMappingUtil.getJobName(GetJobTableDefine.SCOPE),
-                    StringEscapeUtils.escapeHtml4((String) exec.getScope()));
+                    StringEscapeUtils.escapeHtml4(exec.getScope()));
         } else {
             jobData.put(JobMappingUtil.getJobName(GetJobTableDefine.FACILITY_ID),
                     null);
@@ -258,8 +261,8 @@ public class GetJobTreeBusiness {
 
         return false;
     }
-    
-    
+
+
     private String getPath(JobTreeItem treeItem) {
 
         // トップ("ジョブ")の場合は、文字を出力しません。
