@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.business;
@@ -30,7 +30,6 @@ import com.clustercontrol.ws.jobmanagement.JobNodeDetail;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
-import com.necsoft.hinemos.webclient.jobmanagement.JobManagementConstants;
 import com.necsoft.hinemos.webclient.jobmanagement.action.GetNodeDetailTableDefine;
 import com.necsoft.hinemos.webclient.jobmanagement.form.NodeDetailForm;
 import com.necsoft.hinemos.webclient.jobmanagement.util.ConvertListUtil;
@@ -39,7 +38,7 @@ import com.necsoft.hinemos.webclient.util.EndpointManager;
 
 /**
  * This class used for get Node Detail list
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -47,7 +46,7 @@ public class GetNodeDetailBusiness {
 
     /**
      * Get Node Detail list
-     * 
+     *
      * @param form
      *            : NodeDetailForm
      * @param endpointManager
@@ -88,11 +87,10 @@ public class GetNodeDetailBusiness {
 
         //Sanitize
         ConvertListUtil.sanitizeNodeDetailList(list);
-        
-        DataProcess.sortData(form, list,
+
+        DataProcess.doSortListDataInfo(form, list,
                 GetNodeDetailTableDefine.SORT_COLUMN_INDEX,
-                GetNodeDetailTableDefine.SORT_ORDER,
-                JobManagementConstants.NODE_HEADER_NUM);
+                GetNodeDetailTableDefine.SORT_ORDER);
         return list;
     }
 }
\ No newline at end of file
