@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.business;
@@ -26,7 +26,7 @@ import com.necsoft.hinemos.webclient.jobmanagement.action.GetScheduleTableDefine
 
 /**
  * This class used for get schedule header list
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -34,22 +34,29 @@ public class GetScheduleTableDefineBusiness {
 
     /**
      * Get header list
-     * 
+     *
      * @return ArrayList<TableColumnInfoJs>
      * @throws HinemosWebException
      */
-    public ArrayList<TableColumnInfoJs> getScheduleTableDefine(Locale locale)
+    public ArrayList<TableColumnInfoJs> getScheduleTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         // 中間変数を宣言
         ArrayList<TableColumnInfoJs> tblDefine = null;
 
         // スケジュールテーブルヘッダ定義データを取得
-        tblDefine = GetScheduleTableDefine.get(locale);
+        tblDefine = GetScheduleTableDefine.get(locale, isManagerIpRequired);
 
         // スケジュールテーブルヘッダ定義データの項目数チェック
-        if (tblDefine.size() != JobManagementConstants.SCHEDULE_HEADER_NUM) {
-            // 項目数が不足の場合
-            throw new HinemosWebHeaderInvalidException("exception.header.number");
+        if (isManagerIpRequired) {
+            // 項目数が不正の場合
+            if (tblDefine.size() != JobManagementConstants.SCHEDULE_HEADER_NUM_WITH_MANAGER) {
+                throw new HinemosWebHeaderInvalidException("exception.header.number");
+            }
+        } else {
+            // 項目数が不正の場合
+            if (tblDefine.size() != JobManagementConstants.SCHEDULE_HEADER_NUM_WITHOUT_MANAGER) {
+                throw new HinemosWebHeaderInvalidException("exception.header.number");
+            }
         }
         return tblDefine;
     }
