@@ -1,23 +1,26 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -38,7 +41,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * ジョブ[ファイル転送]ビューの一覧情報を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -50,17 +53,18 @@ public class GetForwardFileServlet extends CommonServlet {
 
     /**
      * Get ForwardFile list
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @param response
      *            : HttpServletResponse
      * @throws ServletException
      * @throws IOException
-     * @throws HinemosWebAccessException 
+     * @throws HinemosWebAccessException
      */
+    @Override
     public CommonJson process(HttpServletRequest request,
-            HttpServletResponse response) throws ServletException, IOException, 
+            HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
 
         CommonJson result = new CommonJson();
@@ -71,7 +75,7 @@ public class GetForwardFileServlet extends CommonServlet {
 
             // convert to json
             result = DataProcess.doConvertTableContentToJson(listInfoData);
-            
+
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
@@ -86,14 +90,14 @@ public class GetForwardFileServlet extends CommonServlet {
 
     /**
      * Get ForwardFile list
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @throws HinemosWebException
      */
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest 
+    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest
             request) throws HinemosWebException {
-        
+
         ArrayList<ArrayList<Object>> result = null;
         ForwardFileForm form = new ForwardFileForm();
         PopulateBeanUtils.populateBean(form, request);
@@ -104,20 +108,30 @@ public class GetForwardFileServlet extends CommonServlet {
         }
 
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized (session) {
-            loginManager = (LoginManager) session
-                    .getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
 
             GetForwardFileBusiness business = new GetForwardFileBusiness();
-            result = business.getForwardFile(form, loginManager.endpointManager);
+            String managerIp = form.getManagerIpForSearch();
+            // シングルログインの場合
+            if (managerIp == null || managerIp.trim().isEmpty()) {
+                Iterator<LoginManager> iterator = loginManagerMap.values().iterator();
+                while (iterator.hasNext()) {
+                    LoginManager loginManager = iterator.next();
+                    result = business.getForwardFile(form, loginManager.endpointManager);
+                    break;
+                }
+            } else {
+                result = business.getForwardFile(form, loginManagerMap.get(managerIp).endpointManager);
+            }
         }
         return result;
     }
 
     /**
      * Check valid parameter
-     * 
+     *
      * @param form
      *            : ForwardFileForm
      * @return boolean
