@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
@@ -19,24 +19,31 @@ package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.Map;
+import java.util.Set;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
+
+import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
+import com.necsoft.hinemos.webclient.common.Constants;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.common.JsConstant;
-import com.necsoft.hinemos.webclient.jobmanagement.JobManagementConstants;
 import com.necsoft.hinemos.webclient.jobmanagement.action.GetHistoryTableDefine;
 import com.necsoft.hinemos.webclient.jobmanagement.business.GetHistoryTableDefineBusiness;
 import com.necsoft.hinemos.webclient.json.CommonJson;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
 import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
 import com.necsoft.hinemos.webclient.util.LogUtils;
+import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * This class used for get header list
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -49,7 +56,7 @@ public class GetHistoryTableDefineServlet extends CommonServlet {
 
     /**
      * Get header list
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @param response
@@ -57,23 +64,28 @@ public class GetHistoryTableDefineServlet extends CommonServlet {
      * @throws ServletException
      * @throws IOException
      */
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException {
 
         CommonJson result = new CommonJson();
-        GetHistoryTableDefineBusiness business = null;
         try {
+            HttpSession session = request.getSession();
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            Set<String> managerIpSet = loginManagerMap.keySet();
             //Get header list
-            business = new GetHistoryTableDefineBusiness();
-            ArrayList<TableColumnInfoJs> tblDefine = business.getHistoryTableDefine(request.getLocale());
-            
+            GetHistoryTableDefineBusiness business = new GetHistoryTableDefineBusiness();
+            ArrayList<TableColumnInfoJs> tblDefine = business.getHistoryTableDefine(request.getLocale(), managerIpSet.size() > 1);
+
             //Format column data
             setModelProperties(tblDefine);
+            int maxRowNum = (Integer)request.getSession().getServletContext().getAttribute(Constants.JOB_HISTORY_MAX_ROW);
 
             //Convert header to JSON structure
             result = DataProcess.doConvertTableDefineToJson(
                     tblDefine, true, request.getLocale(),
-                    JobManagementConstants.MAX_HISTORIES,
+                    maxRowNum,
                     GetHistoryTableDefine.SORT_COLUMN_INDEX,
                     GetHistoryTableDefine.SORT_ORDER);
 
@@ -103,7 +115,7 @@ public class GetHistoryTableDefineServlet extends CommonServlet {
 
         TableColumnInfoJs scope = tblDefine.get(GetHistoryTableDefine.SCOPE);
         scope.setFormatter(JsConstant.GRID_FMATTER_SCOPE_TYPE);
-        
+
         Map<String, Object> scopeFmtOpt = new HashMap<String, Object>();
         scopeFmtOpt.put(JsConstant.GRID_FMATTER_SCOPE_TYPE_POSITION,
                 GetHistoryTableDefine.FACILITY_ID);
@@ -114,7 +126,7 @@ public class GetHistoryTableDefineServlet extends CommonServlet {
 
         tblDefine.get(GetHistoryTableDefine.END_SUSPEND_TIME).setFormatter(
                 JsConstant.GRID_FMATTER_DATE_TIME);
-        
+
         tblDefine.get(GetHistoryTableDefine.TRIGGER_TYPE).setFormatter(
                 JsConstant.GRID_FMATTER_TRIGGER_TYPE);
     }
