@@ -1,23 +1,26 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -39,7 +42,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for get Job Detail info
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -51,28 +54,29 @@ public class GetJobDetailServlet extends CommonServlet {
 
     /**
      * Get Job Detail info
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @param response
      *            : HttpServletResponse
      * @throws ServletException
      * @throws IOException
-     * @throws HinemosWebAccessException 
+     * @throws HinemosWebAccessException
      */
+    @Override
     public CommonJson process(HttpServletRequest request, HttpServletResponse response)
             throws ServletException, IOException, HinemosWebAccessException {
-        
+
         // 中間変数を宣言
         CommonJson result = new CommonJson();
-        
+
         try {
             // Get Data
             ArrayList<ArrayList<Object>> list = doLoadListInfoData(request);
 
             // Convert data to JSON structure
             result = DataProcess.doConvertTableContentToJson(list);
-            
+
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
@@ -85,42 +89,54 @@ public class GetJobDetailServlet extends CommonServlet {
             logUtils.error(ex.getMessage(), ex.getCause());
             result = ExceptionHandlerUtils.doBuildCommonJson(
                     ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
-        }        
+        }
         return result;
     }
 
     /**
      * ジョブ[ジョブ詳細]情報一覧データを取得
      */
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request) 
+    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
         throws HinemosWebException {
 
         JobDetailForm form = new JobDetailForm();
         ArrayList<ArrayList<Object>> result = null;
-        
+
         PopulateBeanUtils.populateBean(form, request);
 
         // Check parameters of request
         if (!isValidRequestParam(form)) {
             throw new HinemosWebInvalidRequestParameterException();
         }
-     
+
         //Get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+
             GetJobDetailBusiness business = new GetJobDetailBusiness();
-            result = business.getJobDetail(form, loginManager.endpointManager);
+            String managerIp = form.getManagerIpForSearch();
+            // シングルログインの場合
+            if (managerIp == null || managerIp.trim().isEmpty()) {
+                Iterator<LoginManager> iterator = loginManagerMap.values().iterator();
+                while (iterator.hasNext()) {
+                    LoginManager loginManager = iterator.next();
+                    result = business.getJobDetail(form,
+                            loginManager.endpointManager);
+                    break;
+                }
+            } else {
+                result = business.getJobDetail(form, loginManagerMap.get(managerIp).endpointManager);
+            }
         }
-        
+
         return result;
     }
 
     /**
      * Check valid parameter
-     * 
+     *
      * @param form
      *            : JobDetailForm
      * @return boolean
