@@ -1,23 +1,26 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -39,7 +42,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for get Node Detail info
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -51,7 +54,7 @@ public class GetNodeDetailServlet extends CommonServlet {
 
     /**
      * Get Node Detail info
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @param response
@@ -60,6 +63,7 @@ public class GetNodeDetailServlet extends CommonServlet {
      * @throws IOException
      * @throws HinemosWebAccessException
      */
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -91,7 +95,7 @@ public class GetNodeDetailServlet extends CommonServlet {
 
     /**
      * Get Node Detail info
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @return ArrayList<ArrayList<Object>>
@@ -99,7 +103,7 @@ public class GetNodeDetailServlet extends CommonServlet {
      */
     private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
             throws HinemosWebException {
-        
+
         ArrayList<ArrayList<Object>> result = null;
         NodeDetailForm form = new NodeDetailForm();
         PopulateBeanUtils.populateBean(form, request);
@@ -108,16 +112,26 @@ public class GetNodeDetailServlet extends CommonServlet {
         if (!isValidRequestParam(form)) {
             throw new HinemosWebInvalidRequestParameterException();
         }
-        
+
         // get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized (session) {
-            loginManager = (LoginManager) session
-                    .getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
 
             GetNodeDetailBusiness business = new GetNodeDetailBusiness();
-            result = business.getNodeDetail(form, loginManager.endpointManager);
+            String managerIp = form.getManagerIpForSearch();
+            // シングルログインの場合
+            if (managerIp == null || managerIp.trim().isEmpty()) {
+                Iterator<LoginManager> iterator = loginManagerMap.values().iterator();
+                while (iterator.hasNext()) {
+                    LoginManager loginManager = iterator.next();
+                    result = business.getNodeDetail(form, loginManager.endpointManager);
+                    break;
+                }
+            } else {
+                result = business.getNodeDetail(form, loginManagerMap.get(managerIp).endpointManager);
+            }
         }
 
         return result;
@@ -125,7 +139,7 @@ public class GetNodeDetailServlet extends CommonServlet {
 
     /**
      * Check valid parameter
-     * 
+     *
      * @param form
      *            : NodeDetailForm
      * @return boolean
