@@ -1,23 +1,24 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -38,12 +39,12 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for get Schedule info
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class GetScheduleServlet extends CommonServlet {
-    
+
     private static final long serialVersionUID = -7775038566425028930L;
 
     private static LogUtils logUtils = LogUtils
@@ -51,7 +52,7 @@ public class GetScheduleServlet extends CommonServlet {
 
     /**
      * Get Schedule info
-     * 
+     *
      * @param request
      *            : HttpServletRequest
      * @param response
@@ -60,6 +61,7 @@ public class GetScheduleServlet extends CommonServlet {
      * @throws IOException
      * @throws HinemosWebAccessException
      */
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -93,23 +95,22 @@ public class GetScheduleServlet extends CommonServlet {
     /**
      * スケジュール情報一覧データを取得
      */
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request) 
+    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
         throws HinemosWebException {
-        
+
         ScheduleForm form = new ScheduleForm();
-        ArrayList<ArrayList<Object>> result = null;
-        
+        ArrayList<ArrayList<Object>> result = new ArrayList<ArrayList<Object>>();
+
         PopulateBeanUtils.populateBean(form, request);
 
         //Get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
             GetScheduleBusiness business = new GetScheduleBusiness();
-            result = business.getSchedule(form, loginManager.endpointManager, request.getLocale());
-        }                
+            result.addAll(business.getSchedule(form, loginManagerMap, request.getLocale()));
+        }
         return result;
     }
 }
\ No newline at end of file
