@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.necsoft.hinemos.webclient.jobmanagement.util;
@@ -50,7 +50,7 @@ public class ConvertListUtil {
      * Schedule
      */
     public static ArrayList<ArrayList<Object>> jobScheduleListToArrayList(
-            List<JobSchedule> list, Locale locale) {
+            List<JobSchedule> list, Locale locale, String managerIp) {
 
         ArrayList<ArrayList<Object>> result = new ArrayList<ArrayList<Object>>();
         Iterator<JobSchedule> itr = list.iterator();
@@ -65,14 +65,17 @@ public class ConvertListUtil {
             schedule.add(GetScheduleTableDefine.JOB_NAME, jobSche.getJobName());
             schedule.add(GetScheduleTableDefine.JOBUNIT_ID, jobSche.getJobunitId());
             schedule.add(GetScheduleTableDefine.CALENDAR_ID, jobSche.getCalendarId());
-            schedule.add(GetScheduleTableDefine.SCHEDULE, 
+            schedule.add(GetScheduleTableDefine.SCHEDULE,
                     jobConvertScheduleToString(jobSche.getSchedule(), locale));
             schedule.add(GetScheduleTableDefine.VALID, jobSche.getValid());
             schedule.add(GetScheduleTableDefine.CREATE_USER, jobSche.getCreateUser());
             schedule.add(GetScheduleTableDefine.CREATE_TIME, jobSche.getCreateTime());
             schedule.add(GetScheduleTableDefine.UPDATE_USER, jobSche.getUpdateUser());
             schedule.add(GetScheduleTableDefine.UPDATE_TIME, jobSche.getUpdateTime());
-            
+            if (managerIp != null) {
+                schedule.add(GetScheduleTableDefine.MANAGER, managerIp);
+            }
+
             result.add(schedule);
         }
         return result;
@@ -115,7 +118,7 @@ public class ConvertListUtil {
         }
         return scheduleString;
     }
-    
+
     /**
      * @param list
      */
@@ -136,14 +139,14 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetScheduleTableDefine.JOB_NAME).toString()));
             }
-            
+
             /** スケジュール */
             if (row.get(GetScheduleTableDefine.SCHEDULE) != null) {
                 row.set(GetScheduleTableDefine.SCHEDULE,
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetScheduleTableDefine.SCHEDULE).toString()));
             }
-            
+
             /** 新規作成ユーザ */
             if (row.get(GetScheduleTableDefine.CREATE_USER) != null) {
                 row.set(GetScheduleTableDefine.CREATE_USER,
@@ -164,7 +167,7 @@ public class ConvertListUtil {
      * History
      */
     public static ArrayList<ArrayList<Object>> jobHistoryListToArrayList(
-            List<JobHistory> list) {
+            List<JobHistory> list, String managerIp) {
 
         ArrayList<ArrayList<Object>> result = new ArrayList<ArrayList<Object>>();
         Iterator<JobHistory> itr = list.iterator();
@@ -172,7 +175,7 @@ public class ConvertListUtil {
         while (itr.hasNext()) {
             ArrayList<Object> history = new ArrayList<Object>();
             JobHistory jobHist = itr.next();
-            
+
             history.add(GetHistoryTableDefine.STATUS, jobHist.getStatus());
             history.add(GetHistoryTableDefine.END_STATUS, jobHist.getEndStatus());
             history.add(GetHistoryTableDefine.END_VALUE, jobHist.getEndValue());
@@ -188,6 +191,9 @@ public class ConvertListUtil {
             history.add(GetHistoryTableDefine.END_SUSPEND_TIME, jobHist.getEndDate());
             history.add(GetHistoryTableDefine.TRIGGER_TYPE, JobTriggerTypeConstant.stringToType(jobHist.getJobTriggerType()));
             history.add(GetHistoryTableDefine.TRIGGER_INFO, jobHist.getTriggerInfo());
+            if (managerIp != null) {
+                history.add(GetHistoryTableDefine.MANAGER, managerIp);
+            }
 
             result.add(history);
         }
@@ -195,7 +201,7 @@ public class ConvertListUtil {
         return result;
     }
 
-    public static void sanitizeHistoryList(ArrayList<ArrayList<Object>> list) {
+    public static void sanitizeHistoryList(List<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             List<Object> row = list.get(count);
 
@@ -313,7 +319,7 @@ public class ConvertListUtil {
             }
         }
     }
-    
+
     /**************************************************************************
      * Forward file
      */
@@ -421,63 +427,63 @@ public class ConvertListUtil {
      */
     public static void generateSerializedData(ArrayList<ArrayList<Object>> listInfoData,
             List<JobTreeItem> listItem, int level, String parentId) {
-      
+
       Iterator<JobTreeItem> itr = listItem.iterator();
       boolean isLeaf;
-      
+
       while (itr.hasNext()) {
             JobTreeItem jobTreeItem = itr.next();
-               
+
             if (jobTreeItem.getChildren().size() != 0) {
                 isLeaf = false;
             } else {
                 isLeaf = true;
             }
-            
+
             //Add data
             listInfoData.add(jobDetailListToArrayList(jobTreeItem, level, parentId, isLeaf));
 
             //Check children
             if(!isLeaf)
-            {    
+            {
                 String jobParentId;
                 jobParentId = jobTreeItem.getData().getId();
                 generateSerializedData(listInfoData, jobTreeItem.getChildren(),level+1, jobParentId);
             }
         }
     }
-    
+
     private static ArrayList<Object> jobDetailListToArrayList(
             JobTreeItem jobTreeItem, int level, String parentId, boolean isLeaf) {
 
         ArrayList<Object> jobDetail = new ArrayList<Object>();
         JobInfo jobInfo = jobTreeItem.getData();
         JobDetailInfo jobDetailInfo = jobTreeItem.getDetail();
-        
+
         jobDetail.add(GetJobDetailTableDefine.TREE, "");
-        jobDetail.add(GetJobDetailTableDefine.STATUS, 
+        jobDetail.add(GetJobDetailTableDefine.STATUS,
                 jobDetailInfo.getStatus());
-        jobDetail.add(GetJobDetailTableDefine.END_STATUS, 
+        jobDetail.add(GetJobDetailTableDefine.END_STATUS,
                 jobDetailInfo.getEndStatus());
-        jobDetail.add(GetJobDetailTableDefine.END_VALUE, 
+        jobDetail.add(GetJobDetailTableDefine.END_VALUE,
                 jobDetailInfo.getEndValue());
-        jobDetail.add(GetJobDetailTableDefine.JOB_ID, 
+        jobDetail.add(GetJobDetailTableDefine.JOB_ID,
                 jobInfo.getId());
-        jobDetail.add(GetJobDetailTableDefine.JOB_NAME, 
+        jobDetail.add(GetJobDetailTableDefine.JOB_NAME,
                 jobInfo.getName());
-        jobDetail.add(GetJobDetailTableDefine.JOBUNIT_ID, 
+        jobDetail.add(GetJobDetailTableDefine.JOBUNIT_ID,
                 jobInfo.getJobunitId());
-        jobDetail.add(GetJobDetailTableDefine.JOB_TYPE, 
+        jobDetail.add(GetJobDetailTableDefine.JOB_TYPE,
                 jobInfo.getType());
         jobDetail.add(GetJobDetailTableDefine.FACILITY_ID,
                 jobDetailInfo.getFacilityId());
-        jobDetail.add(GetJobDetailTableDefine.SCOPE, 
+        jobDetail.add(GetJobDetailTableDefine.SCOPE,
                 jobDetailInfo.getScope());
-        jobDetail.add(GetJobDetailTableDefine.WAIT_RULE_TIME, 
+        jobDetail.add(GetJobDetailTableDefine.WAIT_RULE_TIME,
                 jobDetailInfo.getWaitRuleTime());
-        jobDetail.add(GetJobDetailTableDefine.START_RERUN_TIME, 
+        jobDetail.add(GetJobDetailTableDefine.START_RERUN_TIME,
                 jobDetailInfo.getStartDate());
-        jobDetail.add(GetJobDetailTableDefine.END_SUSPEND_TIME, 
+        jobDetail.add(GetJobDetailTableDefine.END_SUSPEND_TIME,
                 jobDetailInfo.getEndDate());
 
         // Add properties for tree grid
@@ -487,10 +493,10 @@ public class ConvertListUtil {
         jobDetail.add(GetJobDetailTableDefine.END_SUSPEND_TIME + 4, isLeaf);
         jobDetail.add(GetJobDetailTableDefine.END_SUSPEND_TIME + 5, true);
         jobDetail.add(GetJobDetailTableDefine.END_SUSPEND_TIME + 6, JsConstant.TREE_LOADED);
-        
+
         return jobDetail;
     }
-    
+
     public static void sanitizeJobDetailList(ArrayList<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             List<Object> row = list.get(count);
