@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.necsoft.hinemos.webclient.jobmanagement.util;
@@ -39,13 +39,14 @@ import com.clustercontrol.ws.jobmanagement.NodeOperationInfo;
 import com.clustercontrol.ws.jobmanagement.NotifyNotFound_Exception;
 import com.clustercontrol.ws.jobmanagement.OutputBasicInfo;
 import com.clustercontrol.ws.jobmanagement.UserNotFound_Exception;
+import com.necsoft.hinemos.webclient.jobmanagement.JobManagementConstants;
 import com.necsoft.hinemos.webclient.util.EndpointManager;
 import com.necsoft.hinemos.webclient.util.EndpointManager.EndpointSetting;
 import com.sun.xml.internal.ws.client.ClientTransportException;
 
 /**
  * Hinemosマネージャとの通信をするクラス。 HAのような複数マネージャ対応のため、このクラスを実装する。
- * 
+ *
  * Hinemosマネージャと通信できない場合は、WebServiceExceptionがthrowされる。
  * WebServiceExeptionが出力された場合は、もう一台のマネージャと通信する。
  */
@@ -83,7 +84,7 @@ public class JobEndpointWrapper {
                 JobEndpoint endpoint = (JobEndpoint) endpointSetting
                         .getEndpoint();
                 JobTreeItem item = endpoint.getJobDetailList(sessionId);
-                setTreeParent(item);
+                setTreeParent(item, null);
                 return item;
             } catch (WebServiceException e) {
                 wse = e;
@@ -95,7 +96,7 @@ public class JobEndpointWrapper {
     }
 
     public static JobTreeItem getJobTree(boolean treeOnly,
-            EndpointManager endpointManager) throws HinemosUnknown_Exception,
+            EndpointManager endpointManager, String managerIp) throws HinemosUnknown_Exception,
             InvalidRole_Exception, InvalidUserPass_Exception,
             JobMasterNotFound_Exception, NotifyNotFound_Exception,
             UserNotFound_Exception, WebServiceException {
@@ -105,7 +106,7 @@ public class JobEndpointWrapper {
                 JobEndpoint endpoint = (JobEndpoint) endpointSetting
                         .getEndpoint();
                 JobTreeItem item = endpoint.getJobTree(treeOnly);
-                setTreeParent(item);
+                setTreeParent(item, managerIp);
                 return item;
             } catch (WebServiceException e) {
                 wse = e;
@@ -116,11 +117,18 @@ public class JobEndpointWrapper {
         throw wse;
     }
 
-    public static void setTreeParent(JobTreeItem item) {
+    public static void setTreeParent(JobTreeItem item, String managerIp) {
         List<JobTreeItem> children = item.getChildren();
         for (JobTreeItem child : children) {
+            JobInfo jobInfo = child.getData();
+            // マルチログインの場合のみ、IPを追加。
+            String jobName = jobInfo.getName();
+            if (managerIp != null && JobManagementConstants.STRING_JOB.equals(jobName)) {
+                jobInfo.setName(jobName + " (" + managerIp + ")");
+            }
+            child.setData(jobInfo);
             child.setParent(item);
-            setTreeParent(child);
+            setTreeParent(child, managerIp);
         }
     }
 
@@ -204,10 +212,10 @@ public class JobEndpointWrapper {
         }
         throw wse;
     }
-    
-    public static void runJob(String jobunitId, String jobId, 
+
+    public static void runJob(String jobunitId, String jobId,
             OutputBasicInfo info, JobTriggerInfo triggerInfo, EndpointManager endpointManager)
-            throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, 
+            throws FacilityNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception,
             InvalidUserPass_Exception, JobInfoNotFound_Exception, JobMasterNotFound_Exception,
             WebServiceException{
         WebServiceException wse = null;
@@ -221,7 +229,7 @@ public class JobEndpointWrapper {
                 m_log.warn("runJob(), " + e.getMessage(), e);
                 endpointManager.changeEndpoint();
             }
-        }        
+        }
         throw wse;
     }
 
