@@ -1,31 +1,35 @@
 /*
- 
-Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.util;
 
+import java.util.Iterator;
 import java.util.Locale;
+import java.util.Set;
+
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.jobmanagement.bean.HistoryFilterPropertyConstant;
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.lang.WebMessages;
+import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
 
 /**
  * 履歴フィルタ用プロパティを作成するクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -33,72 +37,95 @@ public class JobHistoryFilterProperty {
 
     /**
      * 履歴フィルタ用プロパティを取得する
-     * 
+     *
      * @return 履歴フィルタ用プロパティ
-     * 
+     *
      */
-    public static Property getProperty(Locale locale) {
+    public static Property getProperty(Locale locale, Set<String> managerIpSet) {
 
         //開始・再実行日時（自）
         Property m_startFromDate = new Property(
-                HistoryFilterPropertyConstant.START_FROM_DATE, 
-                WebMessages.getString("start", locale), 
+                HistoryFilterPropertyConstant.START_FROM_DATE,
+                WebMessages.getString("start", locale),
                 PropertyConstant.EDITOR_DATETIME);
         //開始・再実行日時（至）
         Property m_startToDate = new Property(
-                HistoryFilterPropertyConstant.START_TO_DATE, 
-                    WebMessages.getString("end", locale), 
+                HistoryFilterPropertyConstant.START_TO_DATE,
+                    WebMessages.getString("end", locale),
                     PropertyConstant.EDITOR_DATETIME);
         //終了・中断日時（自）
         Property m_endFromDate = new Property(
-                HistoryFilterPropertyConstant.END_FROM_DATE, 
-                WebMessages.getString("start", locale), 
+                HistoryFilterPropertyConstant.END_FROM_DATE,
+                WebMessages.getString("start", locale),
                 PropertyConstant.EDITOR_DATETIME);
         //終了・中断日時（至）
         Property m_endToDate = new Property(
-                HistoryFilterPropertyConstant.END_TO_DATE, 
-                WebMessages.getString("end", locale), 
+                HistoryFilterPropertyConstant.END_TO_DATE,
+                WebMessages.getString("end", locale),
                 PropertyConstant.EDITOR_DATETIME);
         //ジョブID
         Property m_jobId = new Property(
-                HistoryFilterPropertyConstant.JOB_ID, 
-                WebMessages.getString("job.id", locale), 
+                HistoryFilterPropertyConstant.JOB_ID,
+                WebMessages.getString("job.id", locale),
                 PropertyConstant.EDITOR_JOB);
         //状態
         Property m_status = new Property(
-                HistoryFilterPropertyConstant.STATUS, 
-                WebMessages.getString("run.status", locale), 
+                HistoryFilterPropertyConstant.STATUS,
+                WebMessages.getString("run.status", locale),
                 PropertyConstant.EDITOR_SELECT);
         //実行契機種別
         Property m_triggerType = new Property(
-                HistoryFilterPropertyConstant.TRIGGER_TYPE, 
-                WebMessages.getString("trigger.type", locale), 
+                HistoryFilterPropertyConstant.TRIGGER_TYPE,
+                WebMessages.getString("trigger.type", locale),
                 PropertyConstant.EDITOR_SELECT);
         //実行契機情報
         Property m_triggerInfo = new Property(
-                HistoryFilterPropertyConstant.TRIGGER_INFO, 
-                WebMessages.getString("trigger.info", locale), 
-                PropertyConstant.EDITOR_TEXT, 
+                HistoryFilterPropertyConstant.TRIGGER_INFO,
+                WebMessages.getString("trigger.info", locale),
+                PropertyConstant.EDITOR_TEXT,
                 DataRangeConstant.VARCHAR_128);
 
         //開始・再実行日時
         Property m_startDate = new Property(
-                HistoryFilterPropertyConstant.START_DATE, 
-                WebMessages.getString("start.rerun.time", locale), 
+                HistoryFilterPropertyConstant.START_DATE,
+                WebMessages.getString("start.rerun.time", locale),
                 PropertyConstant.EDITOR_TEXT);
-        
+
         //終了・中断日時
         Property m_endDate = new Property(
-                HistoryFilterPropertyConstant.END_DATE, 
-                WebMessages.getString("end.suspend.time", locale), 
+                HistoryFilterPropertyConstant.END_DATE,
+                WebMessages.getString("end.suspend.time", locale),
                 PropertyConstant.EDITOR_TEXT);
-        
+
         //実行契機
         Property m_trigger = new Property(
-                HistoryFilterPropertyConstant.TRIGGER, 
-                WebMessages.getString("trigger", locale), 
+                HistoryFilterPropertyConstant.TRIGGER,
+                WebMessages.getString("trigger", locale),
                 PropertyConstant.EDITOR_TEXT);
 
+        // マネージャ列でフィルタ
+        Property m_manager = null;
+        if (managerIpSet.size() > 1) {
+            m_manager = new Property(
+                    RepositoryConstants.FILTER_CONDITION_ID_MANAGER,
+                    WebMessages.getString("manager", locale),
+                    PropertyConstant.EDITOR_SELECT);
+
+            // ログインしたマネージャのIPアドレスすべてを追加
+            Object[][] managerIpValues = new Object[2][];
+            String[] managerIps = new String[managerIpSet.size() + 1];
+            managerIps[0] = "";
+            Iterator<String> iterator = managerIpSet.iterator();
+            for (int i = 1; iterator.hasNext(); i++) {
+                managerIps[i] = iterator.next();
+            }
+            managerIpValues[0] = managerIps;
+            managerIpValues[1] = managerIps;
+            m_manager.setSelectValues(managerIpValues);
+            m_manager.setValue("");
+            m_manager.setModify(PropertyConstant.MODIFY_OK);
+        }
+
      // 値を初期化（状態）
         Object statusValues[][] = {
                 { "", WebMessages.getString("wait", Locale.JAPAN),
@@ -124,7 +151,7 @@ public class JobHistoryFilterProperty {
                 { "", WebMessages.getString("schedule", locale),
                         WebMessages.getString("trigger.manual", locale),
                         WebMessages.getString("trigger.monitor", locale) } };
-        
+
         m_status.setSelectValues(statusValues);
         m_status.setValue("");
         m_triggerType.setSelectValues(triggerValues);
@@ -165,6 +192,9 @@ public class JobHistoryFilterProperty {
         property.addChildren(m_jobId);
         property.addChildren(m_status);
         property.addChildren(m_trigger);
+        if (m_manager != null) {
+            property.addChildren(m_manager);
+        }
 
         // 開始・再実行日時
         m_startDate.removeChildren();
