@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.jobmanagement.util;
@@ -27,14 +27,14 @@ import com.necsoft.hinemos.webclient.jobmanagement.action.GetScheduleTableDefine
 
 /**
  * This class used for Mapping data
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class JobMappingUtil {
     private static final Map<Integer, String> JOB_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
         /**
-         * 
+         *
          */
         private static final long serialVersionUID = 7261193083575860188L;
 
@@ -54,7 +54,7 @@ public class JobMappingUtil {
 
     private static final Map<Integer, String> HISTORY_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
         /**
-		 * 
+		 *
 		 */
         private static final long serialVersionUID = -6098871711845747731L;
 
@@ -74,13 +74,14 @@ public class JobMappingUtil {
             put(GetHistoryTableDefine.END_SUSPEND_TIME, "endSuspendTime");
             put(GetHistoryTableDefine.TRIGGER_TYPE, "triggerType");
             put(GetHistoryTableDefine.TRIGGER_INFO, "triggerInfo");
+            put(GetHistoryTableDefine.MANAGER, "manager");
         }
     };
 
     private static final Map<Integer, String> JOB_DETAIL_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
 
         /**
-		 * 
+		 *
 		 */
         private static final long serialVersionUID = 4862213824718976924L;
 
@@ -103,7 +104,7 @@ public class JobMappingUtil {
 
     private static final Map<Integer, String> JOB_SCHEDULE_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
         /**
-         * 
+         *
          */
         private static final long serialVersionUID = 7261193083575860188L;
 
@@ -120,12 +121,13 @@ public class JobMappingUtil {
             put(GetScheduleTableDefine.CREATE_TIME, "createTime");
             put(GetScheduleTableDefine.UPDATE_USER, "updateUser");
             put(GetScheduleTableDefine.UPDATE_TIME, "updateTime");
+            put(GetScheduleTableDefine.MANAGER, "manager");
         }
     };
-    
+
     private static final Map<Integer, String> JOB_NODE_DETAIL_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
         /**
-         * 
+         *
          */
         private static final long serialVersionUID = 7261193083575860188L;
 
@@ -139,10 +141,10 @@ public class JobMappingUtil {
             put(GetNodeDetailTableDefine.MESSAGE, "message");
         }
     };
-    
+
     private static final Map<Integer, String> JOB_FILE_TRANFER_COLUMN_NAME_MAP = new HashMap<Integer, String>() {
         /**
-         * 
+         *
          */
         private static final long serialVersionUID = 7261193083575860188L;
 
@@ -158,7 +160,7 @@ public class JobMappingUtil {
             put(GetForwardFileTableDefine.END_SUSPEND_TIME, "endSuspendTime");
         }
     };
-    
+
     public static final String getJobName(int id) {
         return JOB_COLUMN_NAME_MAP.get(id);
     }
@@ -170,15 +172,15 @@ public class JobMappingUtil {
     public static final String getJobDetailName(int id) {
         return JOB_DETAIL_COLUMN_NAME_MAP.get(id);
     }
-    
+
     public static final String getJobScheduleName(int id) {
         return JOB_SCHEDULE_COLUMN_NAME_MAP.get(id);
     }
-    
+
     public static final String getJobNodeDetailName(int id) {
         return JOB_NODE_DETAIL_COLUMN_NAME_MAP.get(id);
     }
-    
+
     public static final String getFileTranferName(int id) {
         return JOB_FILE_TRANFER_COLUMN_NAME_MAP.get(id);
     }
