@@ -1,22 +1,24 @@
 /*
- 
-Copyright (C) NEC Corporation 2013. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2013. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2013. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2013. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.action;
 
 import java.util.Locale;
+import java.util.Set;
+
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.monitor.util.EventBatchConfirmPropertyUtil;
 
@@ -27,10 +29,10 @@ public class GetEventBatchConfirmProperty {
 
 	/**
 	 * イベント一括確認用プロパティを取得します。
-	 * 
+	 *
 	 * @return イベント一括確認用プロパティ
 	 */
-	public Property getProperty(Locale locale) {
-		return EventBatchConfirmPropertyUtil.getProperty(locale);
+	public Property getProperty(Locale locale, Set<String> managerIpSet) {
+		return EventBatchConfirmPropertyUtil.getProperty(locale, managerIpSet);
 	}
 }
\ No newline at end of file
