@@ -1,22 +1,23 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.action;
 
 import java.util.Locale;
+import java.util.Set;
 
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.monitor.util.EventFilterPropertyUtil;
@@ -24,9 +25,9 @@ import com.necsoft.hinemos.webclient.monitor.util.EventFilterPropertyUtil;
 
 /**
  * イベント情報フィルタ用プロパティを取得するクライアント側アクションクラス<BR>
- * 
+ *
  * マネージャにSessionBean経由でアクセスし、イベント情報フィルタ用プロパティを取得します。
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -34,10 +35,10 @@ public class GetEventFilterProperty {
 
 	/**
 	 * イベント情報フィルタ用プロパティを取得します。
-	 * 
+	 *
 	 * @return イベント情報フィルタ用プロパティ
 	 */
-	public Property getProperty(Locale locale) {
-		return EventFilterPropertyUtil.getProperty(locale);
+	public Property getProperty(Locale locale, Set<String> managerIpSet) {
+		return EventFilterPropertyUtil.getProperty(locale, managerIpSet);
 	}
 }
\ No newline at end of file
