@@ -74,6 +74,9 @@ public class GetEventListTableDefine {
     /** コメント */
     public static final int COMMENT = 13;
 
+    /** マネージャ */
+    public static final int MANAGER = 14;
+
     /** 初期表示時ソートカラム。 */
     public static final int SORT_COLUMN_INDEX = RECEIVE_TIME;
 
@@ -89,7 +92,7 @@ public class GetEventListTableDefine {
      * @see com.clustercontrol.bean.TableColumnInfo#TableColumnInfoJs(java.lang.String, int, int, int)
      * @see com.clustercontrol.monitor.bean.EventTableDefine
      */
-    public static ArrayList<TableColumnInfoJs> getEventListTableDefine(Locale locale) {
+    public static ArrayList<TableColumnInfoJs> getEventListTableDefine(Locale locale, boolean isManagerIpRequired) {
 
         /** テーブル情報定義配列 */
         ArrayList<TableColumnInfoJs> tableDefine = new ArrayList<TableColumnInfoJs>();
@@ -150,7 +153,13 @@ public class GetEventListTableDefine {
                 WebMessages.getString("comment", locale), 
                 TableColumnInfoJs.NONE, 200, SWT.LEFT, 
                 MonitorMappingUtil.getEventName(COMMENT)));
-
+        if (isManagerIpRequired) {
+            tableDefine.add(
+                    MANAGER,
+                    new TableColumnInfoJs(WebMessages.getString("manager",
+                            locale), TableColumnInfoJs.NONE, 150, SWT.LEFT,
+                            MonitorMappingUtil.getEventName(MANAGER)));
+        }
         return tableDefine;
     }
     
