@@ -42,11 +42,14 @@ public class GetScopeListTableDefine {
     /** スコープ。 */
     public static final int SCOPE = 2;
 
+    /** マネージャ。 */
+    public static final int MANAGER = 3;
+
     /** 更新日時。 */
-    public static final int UPDATE_TIME = 3;
+    public static final int UPDATE_TIME = 4;
 
     /** ソート用データ**/
-    public static final int SORT_VALUE=4;
+    public static final int SORT_VALUE=0;
 
     /** 初期表示時ソートカラム。 */
     public static final int SORT_COLUMN_INDEX = SORT_VALUE;
@@ -67,7 +70,7 @@ public class GetScopeListTableDefine {
      * @see com.clustercontrol.monitor.bean.ScopeTabelDefine
      */
     public static ArrayList<TableColumnInfoJs> getScopeListTableDefine(
-            Locale locale) {
+            Locale locale, boolean isManagerIpRequired) {
         /** 出力用変数 */
         ArrayList<TableColumnInfoJs> tableDefine = new ArrayList<TableColumnInfoJs>();
 
@@ -84,7 +87,14 @@ public class GetScopeListTableDefine {
                 WebMessages.getString("scope", locale),
                 TableColumnInfoJs.FACILITY, 150, SWT.LEFT,
                 MonitorMappingUtil.getScopeName(SCOPE)));
-
+        if (isManagerIpRequired) {
+            // 「マネージャ」列を追加
+            tableDefine.add(
+                    MANAGER,
+                    new TableColumnInfoJs(WebMessages.getString("manager",
+                            locale), TableColumnInfoJs.MANAGER, 150, SWT.LEFT,
+                            MonitorMappingUtil.getScopeName(MANAGER)));
+        }
         return tableDefine;
     }
 }
\ No newline at end of file
