@@ -1,22 +1,23 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.business;
 
 import java.util.Locale;
+import java.util.Set;
 
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
@@ -25,13 +26,13 @@ import com.necsoft.hinemos.webclient.monitor.action.GetEventFilterProperty;
 
 public class GetEventFilterPropertyBusiness {
 
-    public Property getEventFilterProperty(Locale locale)
+    public Property getEventFilterProperty(Locale locale, Set<String> managerIpSet)
             throws HinemosWebException {
         // 中間変数を宣言
         Property propertyEvent = null;
         // イベント情報一覧を取得
         GetEventFilterProperty getEventFilterProperty = new GetEventFilterProperty();
-        propertyEvent = getEventFilterProperty.getProperty(locale);
+        propertyEvent = getEventFilterProperty.getProperty(locale, managerIpSet);
         if (propertyEvent == null) {
                  // フィルタ情報一覧の取得に失敗しました
                  throw new HinemosWebInvalidDataException("exception.data.filter");
