@@ -27,20 +27,26 @@ import com.necsoft.hinemos.webclient.monitor.action.GetEventListTableDefine;
 
 public class GetEventListTableDefineBusiness {
 
-    public ArrayList<TableColumnInfoJs> getEventListTableDefine(Locale locale)
+    public ArrayList<TableColumnInfoJs> getEventListTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         // 中間変数を宣言
         ArrayList<TableColumnInfoJs> tblDefine = null;
 
         // イベントテーブルヘッダー定義データ(EventTableDefine)を取得
-        tblDefine = GetEventListTableDefine.getEventListTableDefine(locale);
+        tblDefine = GetEventListTableDefine.getEventListTableDefine(locale, isManagerIpRequired);
 
         // イベントテーブルヘッダー定義データの項目数チェック
-        if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_EVENT) {
-            // 項目数が不足の場合
-            throw new HinemosWebHeaderInvalidException("exception.header.number");
+        if (isManagerIpRequired) {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_EVENT_WITH_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
+        } else {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_EVENT_WITHOUT_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
         }
-
         return tblDefine;
     }
 }
