@@ -27,18 +27,25 @@ import com.necsoft.hinemos.webclient.monitor.action.GetScopeListTableDefine;
 
 public class GetScopeListTableDefineBusiness {
 
-    public ArrayList<TableColumnInfoJs> getScopeListTableDefine(Locale locale)
+    public ArrayList<TableColumnInfoJs> getScopeListTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         // 中間変数を宣言
         ArrayList<TableColumnInfoJs> tblDefine = null;
 
         // スコープテーブルヘッダー定義データ(ScopeTableDefine)を取得
-        tblDefine = GetScopeListTableDefine.getScopeListTableDefine(locale);
+        tblDefine = GetScopeListTableDefine.getScopeListTableDefine(locale, isManagerIpRequired);
 
         // スコープテーブルヘッダー定義データの項目数チェック
-        if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_SCOPE) {
-            // 項目数が不足の場合
-            throw new HinemosWebHeaderInvalidException("exception.header.number");
+        if (isManagerIpRequired) {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_SCOPE_WITH_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
+        } else {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_SCOPE_WITHOUT_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
         }
         return tblDefine;
     }
