@@ -17,6 +17,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.necsoft.hinemos.webclient.monitor.business;
 
 import java.util.Locale;
+import java.util.Set;
 
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
@@ -24,13 +25,13 @@ import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidDataException;
 import com.necsoft.hinemos.webclient.monitor.action.GetStatusFilterProperty;
 
 public class GetStatusFilterPropertyBusiness {
-    public Property getStatusFilterProperty(Locale locale) throws HinemosWebException {
+    public Property getStatusFilterProperty(Locale locale, Set<String> managerIpSet) throws HinemosWebException {
         // 中間変数を宣言
         Property propertyStatus = null;
         // ステータス情報一覧を取得
         GetStatusFilterProperty getStatusFilterProperty = new GetStatusFilterProperty();
 
-        propertyStatus = getStatusFilterProperty.getProperty(locale);
+        propertyStatus = getStatusFilterProperty.getProperty(locale, managerIpSet);
 
         if (propertyStatus == null) {
             // フィルタ情報一覧の取得に失敗しました
