@@ -27,18 +27,25 @@ import com.necsoft.hinemos.webclient.monitor.action.GetStatusListTableDefine;
 
 public class GetStatusListTableDefineBusiness {
 
-    public ArrayList<TableColumnInfoJs> getStatusListTableDefine(Locale locale)
+    public ArrayList<TableColumnInfoJs> getStatusListTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         // 中間変数を宣言
         ArrayList<TableColumnInfoJs> tblDefine = null;
 
         // ステータステーブルヘッダー定義データ(StatusTableDefine)を取得
-        tblDefine = GetStatusListTableDefine.getStatusListTableDefine(locale);
+        tblDefine = GetStatusListTableDefine.getStatusListTableDefine(locale, isManagerIpRequired);
 
         // ステータステーブルヘッダー定義データの項目数チェック
-        if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_STATUS) {
-            // 項目数が不足の場合
-            throw new HinemosWebHeaderInvalidException("exception.header.number");
+        if (isManagerIpRequired) {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_STATUS_WITH_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
+        } else {
+            if (tblDefine.size() != MonitorConstants.NUMBER_HEADER_STATUS_WITHOUT_MANAGER) {
+                throw new HinemosWebHeaderInvalidException(
+                        "exception.header.number");
+            }
         }
         return tblDefine;
     }
