@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.form;
@@ -22,11 +22,17 @@ public class EventInfoPropertyForm {
     private String pluginId;
 
     private String monitorId;
-    
+
     private String monitorDetailId;
 
     private long receiveTime;
 
+    /**
+     * マネージャIPアドレス<br>
+     * （左ペインのノードを選択する時検索用）
+     */
+    private String managerIpForSearch;
+
     /**
      * @return the facilityId
      */
@@ -88,4 +94,12 @@ public class EventInfoPropertyForm {
         return monitorDetailId;
     }
 
+    public String getManagerIpForSearch() {
+        return managerIpForSearch;
+    }
+
+    public void setManagerIpForSearch(String managerIpForSearch) {
+        this.managerIpForSearch = managerIpForSearch;
+    }
+
 }
