@@ -1,22 +1,24 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.servlet;
 
 import java.io.IOException;
+import java.util.LinkedHashMap;
+import java.util.Set;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -42,7 +44,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * イベント情報データをリフレッシュするクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -52,6 +54,7 @@ public class GetEventInfoPropertyServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetEventInfoPropertyServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -92,14 +95,23 @@ public class GetEventInfoPropertyServlet extends CommonServlet {
         }
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
             GetEventInfoPropertyBusiness business = new GetEventInfoPropertyBusiness();
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            Set<String> managerIpSet = loginManagerMap.keySet();
+            LoginManager loginManager = null;
+            if (managerIpSet.size() <= 1) {
+                for (String managerIp : managerIpSet) {
+                    loginManager = loginManagerMap.get(managerIp);
+                }
+            } else {
+                loginManager = loginManagerMap.get(form.getManagerIpForSearch());
+            }
+
             propertyEvent = business.getEventInfoProperty(form, request.getLocale(), loginManager.endpointManager);
         }
-        
+
         return propertyEvent;
     }
 
