@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.servlet;
@@ -19,12 +19,20 @@ package com.necsoft.hinemos.webclient.monitor.servlet;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Date;
-import java.util.Locale;
+import java.util.HashMap;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+
+import javax.servlet.ServletContext;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
+
 import org.apache.commons.lang3.StringEscapeUtils;
+
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.common.Constants;
@@ -38,10 +46,10 @@ import com.necsoft.hinemos.webclient.json.GridDataJson;
 import com.necsoft.hinemos.webclient.lang.WebMessages;
 import com.necsoft.hinemos.webclient.monitor.MonitorConstants;
 import com.necsoft.hinemos.webclient.monitor.action.GetEventListTableDefine;
-import com.necsoft.hinemos.webclient.monitor.business.EventBatchConfirmBusiness;
 import com.necsoft.hinemos.webclient.monitor.business.ConfirmEventBusiness;
-import com.necsoft.hinemos.webclient.monitor.business.GetEventListBusiness;
+import com.necsoft.hinemos.webclient.monitor.business.EventBatchConfirmBusiness;
 import com.necsoft.hinemos.webclient.monitor.business.EventUnconfirmBusiness;
+import com.necsoft.hinemos.webclient.monitor.business.GetEventListBusiness;
 import com.necsoft.hinemos.webclient.monitor.form.MonitorEventForm;
 import com.necsoft.hinemos.webclient.monitor.util.MonitorMappingUtil;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
@@ -53,7 +61,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * イベント情報データをリフレッシュするクラス
- * 
+ *
  * @version 2.0.0
  * @since 1.0.0
  **/
@@ -63,6 +71,7 @@ public class GetEventListServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetEventListServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -74,21 +83,29 @@ public class GetEventListServlet extends CommonServlet {
             MonitorEventForm form = getDataForm(request);
 
             // Action form
-            boolean ret = doAction(form, request);
+            String unavailableManagerIp = doAction(form, request);
 
             // 中間変数を宣言
-            ArrayList<ArrayList<Object>> listInfoData = doLoadListInfoData(
+            List<ArrayList<Object>> listInfoData = doLoadListInfoData(
                     request, form);
 
             // Create JSON
             result = doConvertToJson(listInfoData);
-            
+
             // 確認／未確認に変更／一括確認の実行結果が失敗の場合
-            if (!ret){
-                result.setMessage(WebMessages.getString("exception.data.access", request.getLocale()));
+            if (unavailableManagerIp != null){
+                HttpSession session = request.getSession(true);
+                @SuppressWarnings("unchecked")
+                LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+                Set<String> managerIpSet = loginManagerMap.keySet();
+                if (managerIpSet.size() > 1) {
+                    result.setMessage(WebMessages.getString("exception.data.operation", request.getLocale()) + "(" + unavailableManagerIp + ")");
+                } else {
+                    result.setMessage(WebMessages.getString("exception.data.operation", request.getLocale()));
+                }
                 result.setResult(1);
             }
-            
+
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
@@ -119,10 +136,10 @@ public class GetEventListServlet extends CommonServlet {
      * 確認／未確認に変更／一括確認の処理を行う
      * @param form
      * @param request
-     * @param namingContext
      * @throws HinemosWebException
      */
-    private boolean doAction(MonitorEventForm form, HttpServletRequest request
+    @SuppressWarnings("unchecked")
+    private String doAction(MonitorEventForm form, HttpServletRequest request
             ) throws HinemosWebException {
         String action;
         // Check action
@@ -130,30 +147,79 @@ public class GetEventListServlet extends CommonServlet {
             action = form.getAction();
             // get loginManager session
             HttpSession session = request.getSession(true);
-            LoginManager loginManager = null;
-            
+
             if (action.equals("confirmed") || action.equals("unconfirm")) {
-                ArrayList<ArrayList<Object>> list = doGetConfirmedData(request);
-                if (list.size() > 0) {
-                    synchronized(session) {
-                        loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-                        if (action.equals("confirmed")) {
-                            return doConfirmed(list, loginManager.endpointManager);
-                        }
-                        else {
-                            return doUnconfirm(list, loginManager.endpointManager);
+                synchronized(session) {
+                    // 操作権限を持っていないマネージャのIP
+                    String unavailableManagerIp = null;
+
+
+                    LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+                    Set<String> managerIpSet = loginManagerMap.keySet();
+                    int columnCount = managerIpSet.size() <= 1 ? MonitorConstants.NUMBER_HEADER_EVENT_WITHOUT_MANAGER : MonitorConstants.NUMBER_HEADER_EVENT_WITH_MANAGER;
+                    ArrayList<ArrayList<Object>> list = doGetConfirmedData(request, columnCount);
+                    if (list.size() > 0) {
+                        if (managerIpSet.size() <= 1) {
+                            for (String managerIp : managerIpSet) {
+                                LoginManager loginManager = loginManagerMap.get(managerIp);
+                                if (action.equals("confirmed")) {
+                                    if (!doConfirmed(list, loginManager.endpointManager) && unavailableManagerIp == null) {
+                                        unavailableManagerIp = managerIp;
+                                    }
+                                } else {
+                                    if (!doUnconfirm(list, loginManager.endpointManager) && unavailableManagerIp == null) {
+                                        unavailableManagerIp = managerIp;
+                                    }
+                                }
+                            }
+                        } else {
+                            Map<String, ArrayList<ArrayList<Object>>> confirmMap = new HashMap<String, ArrayList<ArrayList<Object>>>();
+                            for (int i = 0; i < list.size(); i++) {
+                                ArrayList<Object> row = list.get(i);
+
+                                String managerIp = (String)row.get(GetEventListTableDefine.MANAGER);
+                                if (confirmMap.get(managerIp) == null) {
+                                    ArrayList<ArrayList<Object>> dataList = new ArrayList<ArrayList<Object>>();
+                                    dataList.add(row);
+                                    confirmMap.put(managerIp, dataList);
+                                } else {
+                                    ArrayList<ArrayList<Object>> dataList = confirmMap.get(managerIp);
+                                    dataList.add(row);
+                                    confirmMap.put(managerIp, dataList);
+                                }
+                            }
+
+                            Set<String> managerIpSetInconfirmMap = confirmMap.keySet();
+                            for (String managerIp : managerIpSetInconfirmMap) {
+                                LoginManager loginManager = loginManagerMap.get(managerIp);
+                                if (action.equals("confirmed")) {
+                                    if (!doConfirmed(confirmMap.get(managerIp), loginManager.endpointManager) && unavailableManagerIp == null) {
+                                        unavailableManagerIp = managerIp;
+                                    }
+                                } else {
+                                    if (!doUnconfirm(confirmMap.get(managerIp), loginManager.endpointManager) && unavailableManagerIp == null) {
+                                        unavailableManagerIp = managerIp;
+                                    }
+                                }
+                            }
+
                         }
+                        return unavailableManagerIp;
                     }
+
                 }
             } else if (action.equals("batchconfirm")) {
+
                 Property condition = doLoadConditionBatchConfirm(request);
                 synchronized(session) {
-                    loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-                    return doBatchConfirm(form, condition, loginManager.endpointManager, request.getLocale());
+                    LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+                    EventBatchConfirmBusiness eventBusiness = new EventBatchConfirmBusiness();
+
+                    return eventBusiness.batchconfirm(form, condition, loginManagerMap, request.getLocale());
                 }
             }
         }
-        return true;
+        return null;
     }
 
     /**
@@ -165,9 +231,9 @@ public class GetEventListServlet extends CommonServlet {
         ConfirmEventBusiness eventBusiness = new ConfirmEventBusiness();
         return eventBusiness.confirm(list, endpointManager);
     }
-    
+
     /**
-     * 
+     *
      * @param list
      * @param endpointManager
      * @throws HinemosWebException
@@ -177,44 +243,34 @@ public class GetEventListServlet extends CommonServlet {
         EventUnconfirmBusiness eventBusiness = new EventUnconfirmBusiness();
         return eventBusiness.unconfirm(list, endpointManager);
     }
-    
-    /**
-     * 
-     * @param form
-     * @param condition
-     * @param endpointManager
-     * @param locale
-     * @throws HinemosWebException
-     */
-    private boolean doBatchConfirm(MonitorEventForm form,
-            Property condition, EndpointManager endpointManager, Locale locale) throws HinemosWebException {
-            EventBatchConfirmBusiness eventBusiness = new EventBatchConfirmBusiness();
-            return eventBusiness.batchconfirm(form, condition, endpointManager, locale);
-    }
-    
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(
+
+    private List<ArrayList<Object>> doLoadListInfoData(
             HttpServletRequest request, MonitorEventForm form) throws HinemosWebException {
-        ArrayList<ArrayList<Object>> listLogData;
+        List<ArrayList<Object>> listLogData = new ArrayList<ArrayList<Object>>();
 
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
+        ServletContext application = request.getSession().getServletContext();
+        int maxNum = (Integer)application.getAttribute(Constants.MONITOR_EVENT_MAX_ROW);
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            // Check filter
-            if (form.isFilter()) {
-                Property condition = doLoadCondition(request);
-                GetEventListBusiness business = new GetEventListBusiness();
-                listLogData = business.getEventList(form, condition, loginManager.endpointManager, request.getLocale());
-            } else {
-                GetEventListBusiness business = new GetEventListBusiness();
-                listLogData = business.getEventList(form, null, loginManager.endpointManager, request.getLocale());
-            }
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            form.setMaxRowNum(maxNum);
+                // Check filter
+                if (form.isFilter()) {
+                    Property condition = doLoadCondition(request);
+                    GetEventListBusiness business = new GetEventListBusiness();
+                    listLogData = business.getEventList(form, condition,loginManagerMap, request.getLocale());
+                } else {
+                    GetEventListBusiness business = new GetEventListBusiness();
+                    listLogData = business.getEventList(form, null,
+                            loginManagerMap, request.getLocale());
+                }
         }
 
         return listLogData;
     }
-    
+
     /**
      * @param request
      * @return
@@ -223,7 +279,7 @@ public class GetEventListServlet extends CommonServlet {
     private Property doLoadCondition(HttpServletRequest request)
             throws HinemosWebException {
         HttpSession session = request.getSession(true);
-        
+
         if (session.getAttribute(MonitorConstants.EVENT_FILTER_PROPERTIES) == null) {
             // HTTPセッションのタイムアウトが発生しました。ログアウトします。
             throw new HinemosWebException("message.sessiontimeout");
@@ -238,19 +294,19 @@ public class GetEventListServlet extends CommonServlet {
     private Property doLoadConditionBatchConfirm(HttpServletRequest request)
         throws HinemosWebException {
         HttpSession session = request.getSession(true);
-        
+
         if (session.getAttribute(MonitorConstants.EVENT_BATCH_CONFIRM_PROPERTIES) == null) {
             // HTTPセッションのタイムアウトが発生しました。ログアウトします。
             throw new HinemosWebException("message.sessiontimeout");
         }
-        
+
         Property condition = (Property) session
                 .getAttribute(MonitorConstants.EVENT_BATCH_CONFIRM_PROPERTIES);
         convertCondition(request, condition);
         return condition;
     }
-    
-    private GridDataJson doConvertToJson(ArrayList<ArrayList<Object>> listInfoData)
+
+    private GridDataJson doConvertToJson(List<ArrayList<Object>> listInfoData)
             throws HinemosWebException {
         return DataProcess.doConvertTableContentToJson(listInfoData);
     }
@@ -261,7 +317,7 @@ public class GetEventListServlet extends CommonServlet {
      * @throws HinemosWebException
      */
     private ArrayList<ArrayList<Object>> doGetConfirmedData(
-            HttpServletRequest request) throws HinemosWebException {
+            HttpServletRequest request, int columnCount) throws HinemosWebException {
         ArrayList<ArrayList<Object>> list = new ArrayList<ArrayList<Object>>();
         String actionData = Constants.ACTION_DATA_REQUEST;
         int numData;
@@ -276,15 +332,15 @@ public class GetEventListServlet extends CommonServlet {
                 // イベントの確認に失敗しました
                 throw new HinemosWebInvalidRequestParameterException(
                         "exception.data.confirm");
-            } else if (numData > Constants.EVENT_ROW_NUM) {
-                numData = Constants.EVENT_ROW_NUM;
+            } else if (numData > (Integer)request.getSession().getServletContext().getAttribute(Constants.MONITOR_EVENT_MAX_ROW)) {
+                numData = (Integer)request.getSession().getServletContext().getAttribute(Constants.MONITOR_EVENT_MAX_ROW);
             }
         }
 
         for (int count = 0; count < numData; count++) {
             ArrayList<Object> row = new ArrayList<Object>();
-            String[] row_data = new String[MonitorConstants.NUMBER_HEADER_EVENT];
-            for (int cnt_col = 0; cnt_col < MonitorConstants.NUMBER_HEADER_EVENT; cnt_col++) {
+            String[] row_data = new String[columnCount];
+            for (int cnt_col = 0; cnt_col < columnCount; cnt_col++) {
                 String row_name = getNameRequestParam(actionData, count,
                         MonitorMappingUtil.getEventName(cnt_col));
                 if (request.getParameter(row_name) == null) {
@@ -313,9 +369,9 @@ public class GetEventListServlet extends CommonServlet {
 
             row.add(GetEventListTableDefine.PRIORITY,
                 row_data[GetEventListTableDefine.PRIORITY]);
-            row.add(GetEventListTableDefine.RECEIVE_TIME, 
+            row.add(GetEventListTableDefine.RECEIVE_TIME,
                 new Date(receiveTime));
-            row.add(GetEventListTableDefine.OUTPUT_DATE, 
+            row.add(GetEventListTableDefine.OUTPUT_DATE,
                 new Date(outputDate));
             row.add(GetEventListTableDefine.PLUGIN_ID, StringEscapeUtils
                 .unescapeHtml4(row_data[GetEventListTableDefine.PLUGIN_ID]));
@@ -339,6 +395,10 @@ public class GetEventListServlet extends CommonServlet {
                 row_data[GetEventListTableDefine.CONFIRM_USER]);
             row.add(GetEventListTableDefine.COMMENT, StringEscapeUtils
                 .unescapeHtml4(row_data[GetEventListTableDefine.COMMENT]));
+            if (MonitorConstants.NUMBER_HEADER_EVENT_WITH_MANAGER == columnCount) {
+                row.add(GetEventListTableDefine.MANAGER, StringEscapeUtils
+                        .unescapeHtml4(row_data[GetEventListTableDefine.MANAGER]));
+            }
             list.add(row);
         }
 
