@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.servlet;
@@ -19,13 +19,17 @@ package com.necsoft.hinemos.webclient.monitor.servlet;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Set;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
 
+import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
 import com.necsoft.hinemos.webclient.common.Constants;
 import com.necsoft.hinemos.webclient.common.CssClass;
@@ -40,10 +44,11 @@ import com.necsoft.hinemos.webclient.monitor.business.GetEventListTableDefineBus
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
 import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
 import com.necsoft.hinemos.webclient.util.LogUtils;
+import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * GetEventListTableDefineServlet
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -53,16 +58,22 @@ public class GetEventListTableDefineServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetEventListTableDefineServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException, HinemosWebAccessException {
 
         CommonJson result = new CommonJson();
 
         try {
-            ArrayList<TableColumnInfoJs> tblDefine = getEventListTableDefine(request);
+            HttpSession session = request.getSession();
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            Set<String> managerIpSet = loginManagerMap.keySet();
+            ArrayList<TableColumnInfoJs> tblDefine = getEventListTableDefine(request, managerIpSet.size() > 1);
             setModelProperties(tblDefine);
+            int eventMaxRow = (Integer)request.getSession().getServletContext().getAttribute(Constants.MONITOR_EVENT_MAX_ROW);
             result = doConvertToJson(tblDefine, request.getLocale(),
-                    Constants.EVENT_ROW_NUM,
+                    eventMaxRow,
                     GetEventListTableDefine.SORT_COLUMN_INDEX,
                     GetEventListTableDefine.SORT_ORDER);
         } catch (Exception ex) {
@@ -79,10 +90,10 @@ public class GetEventListTableDefineServlet extends CommonServlet {
      * @throws HinemosWebException
      */
     private ArrayList<TableColumnInfoJs> getEventListTableDefine(
-            HttpServletRequest request) throws HinemosWebException {
+            HttpServletRequest request, boolean isManagerIpRequired) throws HinemosWebException {
         GetEventListTableDefineBusiness business = new GetEventListTableDefineBusiness();
         ArrayList<TableColumnInfoJs> tblDefine = business
-                .getEventListTableDefine(request.getLocale());
+                .getEventListTableDefine(request.getLocale(), isManagerIpRequired);
         return tblDefine;
     }
 
