@@ -1,29 +1,30 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.servlet;
 
 /**
  * 監視[スコープ]ビューの一覧情報を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -47,7 +48,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * スコープ情報データをリフレッシュするクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -57,6 +58,7 @@ public class GetScopeListServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetScopeListServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -88,25 +90,23 @@ public class GetScopeListServlet extends CommonServlet {
 
     /**
      * @param request
-     * @param namingContext
      * @return
      * @throws HinemosWebException
      */
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest 
+    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest
         request) throws HinemosWebException {
         // スコープ情報一覧データ(ScopeInfoData)を取得
         MonitorScopeForm form = new MonitorScopeForm();
         PopulateBeanUtils.populateBean(form, request);
         GetScopeListBusiness business = new GetScopeListBusiness();
         ArrayList<ArrayList<Object>> scopeList = null;
-        
+
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-
-            scopeList = business.getScopeList(form, loginManager.endpointManager);
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            scopeList = business.getScopeList(form, loginManagerMap);
         }
 
         return scopeList;
