@@ -19,13 +19,17 @@ package com.necsoft.hinemos.webclient.monitor.servlet;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Set;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
 
+import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.bean.TableColumnInfoJs;
 import com.necsoft.hinemos.webclient.common.Constants;
 import com.necsoft.hinemos.webclient.common.CssClass;
@@ -39,6 +43,7 @@ import com.necsoft.hinemos.webclient.monitor.business.GetScopeListTableDefineBus
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
 import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
 import com.necsoft.hinemos.webclient.util.LogUtils;
+import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * GetScopeListTableDefineServlet
@@ -59,8 +64,12 @@ public class GetScopeListTableDefineServlet extends CommonServlet {
         CommonJson result = new CommonJson();
 
         try {
+            HttpSession session = request.getSession();
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            Set<String> managerIpSet = loginManagerMap.keySet();
             ArrayList<TableColumnInfoJs> tblDefine = getScopeListTableDefine(request
-                    .getLocale());
+                    .getLocale(), managerIpSet.size() > 1);
 
             setModelProperties(tblDefine);
 
@@ -82,10 +91,10 @@ public class GetScopeListTableDefineServlet extends CommonServlet {
      * @return
      * @throws HinemosWebException
      */
-    private ArrayList<TableColumnInfoJs> getScopeListTableDefine(Locale locale)
+    private ArrayList<TableColumnInfoJs> getScopeListTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         return new GetScopeListTableDefineBusiness()
-                .getScopeListTableDefine(locale);
+                .getScopeListTableDefine(locale, isManagerIpRequired);
     }
 
     /**
