@@ -1,24 +1,27 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.necsoft.hinemos.webclient.monitor.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
+import java.util.List;
 
+import javax.servlet.ServletContext;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -26,6 +29,7 @@ import javax.servlet.http.HttpSession;
 
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.bean.Property;
+import com.necsoft.hinemos.webclient.common.Constants;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
@@ -43,7 +47,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * ステータス情報データをリフレッシュするクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -53,6 +57,7 @@ public class GetStatusListServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetStatusListServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -61,7 +66,7 @@ public class GetStatusListServlet extends CommonServlet {
 
         try {
             // Get data
-            ArrayList<ArrayList<Object>> listInfoData = doLoadListInfoData(request);
+            List<ArrayList<Object>> listInfoData = doLoadListInfoData(request);
 
             // Create JSON
             result = doConvertToJson(listInfoData);
@@ -72,43 +77,50 @@ public class GetStatusListServlet extends CommonServlet {
         } catch (HinemosWebRemoteException ex) {
             logUtils.error(ex.getMessage(), ex.getCause());
             result = ExceptionHandlerUtils.doBuildCommonJson(
-                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(), request.getLocale());
+                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(),
+                    request.getLocale());
 
         } catch (Exception ex) {
             logUtils.error(ex.getMessage(), ex.getCause());
             result = ExceptionHandlerUtils.doBuildCommonJson(
-                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
+                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(),
+                    request.getLocale());
         }
         return result;
     }
 
     /**
      * @param request
-     * @param namingContext
      * @return
      * @throws HinemosWebException
      */
-    private ArrayList<ArrayList<Object>> doLoadListInfoData(
+    private List<ArrayList<Object>> doLoadListInfoData(
             HttpServletRequest request) throws HinemosWebException {
         // 中間変数を宣言
-        ArrayList<ArrayList<Object>> listInfoData = null;
+        List<ArrayList<Object>> listInfoData = null;
         MonitorStatusForm form = new MonitorStatusForm();
         PopulateBeanUtils.populateBean(form, request);
-        
-        //get loginManager session
+
+        // get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
-        synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+        ServletContext application = request.getSession().getServletContext();
+        int maxNum = (Integer)application.getAttribute(Constants.MONITOR_STATUS_MAX_ROW);
+        synchronized (session) {
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session
+                    .getAttribute(AccessControlConstants.LOGIN_MANAGER);
+            form.setMaxRowNum(maxNum);
 
             // Check filter
             if (form.isFilter()) {
                 Property condition = doLoadCondition(request);
                 GetStatusListBusiness business = new GetStatusListBusiness();
-                listInfoData = business.getStatusList(form, condition, loginManager.endpointManager, request.getLocale());
+                listInfoData = business.getStatusList(form, condition,
+                        loginManagerMap, request.getLocale());
             } else {
                 GetStatusListBusiness business = new GetStatusListBusiness();
-                listInfoData = business.getStatusList(form, null, loginManager.endpointManager, request.getLocale());
+                listInfoData = business.getStatusList(form, null,
+                        loginManagerMap, request.getLocale());
             }
         }
 
@@ -123,12 +135,12 @@ public class GetStatusListServlet extends CommonServlet {
     private Property doLoadCondition(HttpServletRequest request)
             throws HinemosWebException {
         HttpSession session = request.getSession(true);
-        
+
         if (session.getAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES) == null) {
             // HTTPセッションのタイムアウトが発生しました。ログアウトします。
             throw new HinemosWebException("message.sessiontimeout");
         }
-        
+
         Property condition = (Property) session
                 .getAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES);
 
@@ -142,7 +154,7 @@ public class GetStatusListServlet extends CommonServlet {
      * @return
      */
     private GridDataJson doConvertToJson(
-            ArrayList<ArrayList<Object>> listInfoData) {
+            List<ArrayList<Object>> listInfoData) {
         return DataProcess.doConvertTableContentToJson(listInfoData);
     }
 }
\ No newline at end of file
