@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.monitor.util;
@@ -44,7 +44,7 @@ public class ConvertListUtil {
      * @return
      */
     public static ArrayList<ArrayList<Object>> scopeInfoDataListToArrayList(
-            List<ScopeDataInfo> list) {
+            List<ScopeDataInfo> list, String managerIp) {
 
         ArrayList<ArrayList<Object>> ret = new ArrayList<ArrayList<Object>>();
         Iterator<ScopeDataInfo> itr = list.iterator();
@@ -53,21 +53,18 @@ public class ConvertListUtil {
             ArrayList<Object> status = new ArrayList<Object>();
             ScopeDataInfo scopeInfoData = itr.next();
 
-            status.add(GetScopeListTableDefine.PRIORITY, 
+            status.add(GetScopeListTableDefine.PRIORITY,
                     scopeInfoData.getPriority());
-            
+
             status.add(GetScopeListTableDefine.FACILITY_ID,
                     scopeInfoData.getFacilityId());
-            
+
             status.add(GetScopeListTableDefine.SCOPE,
                     scopeInfoData.getFacilityPath());
-            
-            status.add(GetScopeListTableDefine.UPDATE_TIME,
-                    scopeInfoData.getOutputDate());
-            
-            status.add(GetScopeListTableDefine.SORT_VALUE,
-                    scopeInfoData.getSortValue());
 
+            if (managerIp != null) {
+                status.add(GetScopeListTableDefine.MANAGER, managerIp);
+            }
             ret.add(status);
         }
 
@@ -99,7 +96,7 @@ public class ConvertListUtil {
      * Status
      */
     public static ArrayList<ArrayList<Object>> statusInfoDataListToArrayList(
-            List<StatusDataInfo> list) {
+            List<StatusDataInfo> list, String managerIp) {
 
         ArrayList<ArrayList<Object>> ret = new ArrayList<ArrayList<Object>>();
         Iterator<StatusDataInfo> itr = list.iterator();
@@ -141,6 +138,9 @@ public class ConvertListUtil {
             status.add(GetStatusListTableDefine.MESSAGE,
                     statusInfoData.getMessage());
 
+            if (managerIp != null) {
+                status.add(GetStatusListTableDefine.MANAGER, managerIp);
+            }
             ret.add(status);
         }
 
@@ -151,7 +151,7 @@ public class ConvertListUtil {
     /**
      * @param list
      */
-    public static void sanitizeStatusInfoData(ArrayList<ArrayList<Object>> list) {
+    public static void sanitizeStatusInfoData(List<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             ArrayList<Object> row = list.get(count);
             if (row.get(GetStatusListTableDefine.PLUGIN_ID) != null) {
@@ -159,19 +159,19 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetStatusListTableDefine.PLUGIN_ID).toString()));
             }
-            
+
             if (row.get(GetStatusListTableDefine.MONITOR_ID) != null) {
                 row.set(GetStatusListTableDefine.MONITOR_ID,
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetStatusListTableDefine.MONITOR_ID).toString()));
             }
-            
+
             if (row.get(GetStatusListTableDefine.MONITOR_DETAIL_ID) != null) {
                 row.set(GetStatusListTableDefine.MONITOR_DETAIL_ID,
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetStatusListTableDefine.MONITOR_DETAIL_ID).toString()));
             }
-            
+
             if (row.get(GetStatusListTableDefine.FACILITY_ID) != null) {
                 row.set(GetStatusListTableDefine.FACILITY_ID,
                         StringEscapeUtils.escapeHtml4(row.get(
@@ -208,15 +208,15 @@ public class ConvertListUtil {
      * Event
      */
     /**
-     * 
+     *
      * SessionBean経由で取得されたEventDataInfoのリストを、
      * 表示用のリスト（ArrayListの二次元配列）に変換するためのメソッドです。
-     * 
+     *
      * @param list
      * @return
      */
     public static ArrayList<ArrayList<Object>> eventLogDataListToArrayList(
-            List<EventDataInfo> list) {
+            List<EventDataInfo> list, String managerIp) {
 
         ArrayList<ArrayList<Object>> ret = new ArrayList<ArrayList<Object>>();
         Iterator<EventDataInfo> itr = list.iterator();
@@ -266,7 +266,11 @@ public class ConvertListUtil {
 
             event.add(GetEventListTableDefine.COMMENT,
                     eventLogData.getComment());
-            
+
+            if (managerIp != null) {
+                event.add(GetEventListTableDefine.MANAGER, managerIp);
+            }
+
             ret.add(event);
         }
 
@@ -276,7 +280,7 @@ public class ConvertListUtil {
     /**
      * @param list
      */
-    public static void sanitizeEventDataInfo(ArrayList<ArrayList<Object>> list) {
+    public static void sanitizeEventDataInfo(List<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             ArrayList<Object> row = list.get(count);
 
@@ -291,7 +295,7 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetEventListTableDefine.MONITOR_ID).toString()));
             }
-            
+
             if (row.get(GetEventListTableDefine.MONITOR_DETAIL_ID) != null) {
                 row.set(GetEventListTableDefine.MONITOR_DETAIL_ID,
                         StringEscapeUtils.escapeHtml4(row.get(
@@ -327,13 +331,13 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetEventListTableDefine.MESSAGE).toString()));
             }
-            
+
             if (row.get(GetEventListTableDefine.CONFIRM_USER) != null) {
                 row.set(GetEventListTableDefine.CONFIRM_USER,
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetEventListTableDefine.CONFIRM_USER).toString()));
             }
-            
+
             if (row.get(GetEventListTableDefine.COMMENT) != null) {
                 row.set(GetEventListTableDefine.COMMENT,
                         StringEscapeUtils.escapeHtml4(row.get(
@@ -343,11 +347,11 @@ public class ConvertListUtil {
     }
 
     /**
-     * 
+     *
      * 監視[イベント]ビューに表示される内容を基にして、 EventDataInfoのリストに変換するためのメソッドです。
-     * 
+     *
      * オリジナルメッセージのように、表示されていない項目については、 セットされないので注意してください。
-     * 
+     *
      * @param list
      * @return
      */
@@ -387,7 +391,7 @@ public class ConvertListUtil {
                 .get(GetEventListTableDefine.CONFIRM_USER);
             String comment = (String) event
                 .get(GetEventListTableDefine.COMMENT);
-            
+
             EventDataInfo eventLogData = new EventDataInfo();
             eventLogData.setPriority(priority);
             eventLogData.setOutputDate(outputDate.getTime());
@@ -403,7 +407,7 @@ public class ConvertListUtil {
             eventLogData.setConfirmed(confirmFlg);
             eventLogData.setConfirmUser(confirmUser);
             eventLogData.setComment(comment);
-            
+
             eventLogDataList.add(eventLogData);
         }
 
