@@ -94,7 +94,8 @@ public class MonitorEndpointWrapper {
 		for (EndpointSetting endpointSetting : endpointManager.getMonitorEndpoint()) {
 			try {
 				MonitorEndpoint endpoint = (MonitorEndpoint) endpointSetting.getEndpoint();
-				return endpoint.getScopeList(facilityId, statusFlag, eventFlag, orderFlg);
+                    return endpoint.getScopeList(facilityId, statusFlag,
+                            eventFlag, orderFlg);
 			} catch (WebServiceException e) {
 				wse = e;
 				if (e instanceof ClientTransportException) {
