@@ -49,6 +49,7 @@ public class MonitorMappingUtil {
             put(GetEventListTableDefine.CONFIRMED, "confirmed");
             put(GetEventListTableDefine.CONFIRM_USER, "confirmUser");
             put(GetEventListTableDefine.COMMENT, "comment");
+            put(GetEventListTableDefine.MANAGER, "manager");
         }
     };
     
@@ -70,6 +71,7 @@ public class MonitorMappingUtil {
             put(GetStatusListTableDefine.OUTPUT_TIME, "outputTime");
             put(GetStatusListTableDefine.MESSAGE_ID, "messageId");
             put(GetStatusListTableDefine.MESSAGE, "message");
+            put(GetStatusListTableDefine.MANAGER, "manager");
         }
     };
     
@@ -83,6 +85,7 @@ public class MonitorMappingUtil {
             put(GetScopeListTableDefine.PRIORITY, "priority");
             put(GetScopeListTableDefine.FACILITY_ID, "facilityId");
             put(GetScopeListTableDefine.SCOPE, "scope");
+            put(GetScopeListTableDefine.MANAGER, "manager");
         }
     };
 
