@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository;
@@ -34,13 +34,18 @@ public class RepositoryConstants {
                 NodeConstant.FILE_SYSTEM_LIST);
     }
 
-    public static final int NODE_LIST_TABLE_HEADER_NUM = 5;
+    public static final int NODE_LIST_TABLE_HEADER_NUM_WITHOUT_MANAGER = 5;
+    public static final int NODE_LIST_TABLE_HEADER_NUM_WITH_MANAGER = 6;
 
     public static final int NODE_SCOPE_TABLE_HEADER_NUM = 1;
 
     public static final int SCOPE_LIST_TABLE_HEADER_NUM = 3;
-    
-    public static final int AGENT_LIST_TABLE_HEADER_NUM = 5;
+
+    public static final int AGENT_LIST_TABLE_HEADER_NUM_WITHOUT_MANAGER = 5;
+    public static final int AGENT_LIST_TABLE_HEADER_NUM_WITH_MANAGER = 6;
+
+    /** フィルタダイアログのマネージャ項目のID */
+    public static final String FILTER_CONDITION_ID_MANAGER = "manager";
 
     /**
      * @param id
