@@ -1,28 +1,30 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.action;
 
 import java.util.Locale;
+import java.util.Set;
+
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.repository.util.NodeFilterProperty;
 
 /**
  * ノードフィルタ属性情報を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -30,10 +32,10 @@ public class GetNodeFilterProperty {
 
     /**
      * ノードフィルタ属性情報を取得します。
-     * 
+     *
      * @return
      */
-    public Property getProperty(Locale locale) {
-        return NodeFilterProperty.getProperty(locale);
+    public Property getProperty(Locale locale, Set<String> managerIpSet) {
+        return NodeFilterProperty.getProperty(locale, managerIpSet);
     }
 }
\ No newline at end of file
