@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.action;
@@ -37,12 +37,12 @@ import com.necsoft.hinemos.webclient.util.PropertyUtil;
 public class GetNodeList {
     /**
      * 全てのノード一覧を取得します。
-     * 
+     *
      * @return ノード一覧
      */
-    public ArrayList<ArrayList<Object>> getAll(EndpointManager endpointManager) 
+    public ArrayList<ArrayList<Object>> getAll(EndpointManager endpointManager, String managerIp)
             throws HinemosWebException {
-        
+
         List<NodeInfo> records = null;
         try {
             records = RepositoryEndpointWrapper.getNodeListAll(endpointManager);
@@ -59,24 +59,24 @@ public class GetNodeList {
             // Hinemosマネージャより応答がありませんでした。ログアウトします。
             throw new HinemosWebException("message.force.disconnect");
         }
-                
-        ArrayList<ArrayList<Object>> list = ConvertListUtil.nodeInfoListToArrayList(records);
+
+        ArrayList<ArrayList<Object>> list = ConvertListUtil.nodeInfoListToArrayList(records, managerIp);
         return list;
     }
 
     /**
      * propertyの条件にヒットするノードの一覧を返します。
-     * 
+     *
      * @param property
      * @return ノード一覧
      */
-    public ArrayList<ArrayList<Object>> get(Property property, 
-            EndpointManager endpointManager) throws HinemosWebException {
-        
+    public ArrayList<ArrayList<Object>> get(Property property,
+            EndpointManager endpointManager, String managerIp) throws HinemosWebException {
+
         PropertyUtil.deletePropertyDefine(property);
 
         List<NodeInfo> records = null;
-        try {            
+        try {
             NodeInfo nodeInfo = null;
             nodeInfo = NodePropertyUtil.property2node(property);
             records = RepositoryEndpointWrapper.getFilterNodeList(nodeInfo, endpointManager);
@@ -94,7 +94,7 @@ public class GetNodeList {
             throw new HinemosWebException("message.force.disconnect");
         }
 
-        ArrayList<ArrayList<Object>> list = ConvertListUtil.nodeInfoListToArrayList(records);
+        ArrayList<ArrayList<Object>> list = ConvertListUtil.nodeInfoListToArrayList(records, managerIp);
         return list;
     }
 }
\ No newline at end of file
