@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.action;
@@ -25,7 +25,7 @@ import com.necsoft.hinemos.webclient.repository.util.RepositoryMappingUtil;
 
 /**
  * 登録ノード一覧テーブルの定義を取得するクライアント側アクションクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -46,6 +46,9 @@ public class GetNodeListTableDefine {
     /** 説明 */
     public static final int DESCRIPTION = 4;
 
+    /** マネージャ */
+    public static final int MANAGER = 5;
+
     /** 初期表示時ソートカラム */
     public static final int SORT_COLUMN_INDEX = FACILITY_ID;
 
@@ -54,24 +57,24 @@ public class GetNodeListTableDefine {
 
     /**
      * 全てのノード一覧を取得します。
-     * 
+     *
      * @return ノード一覧
      */
-    public static ArrayList<TableColumnInfoJs> get(Locale locale) {
+    public static ArrayList<TableColumnInfoJs> get(Locale locale, boolean isManagerIpRequired) {
         /** 出力用変数 */
         ArrayList<TableColumnInfoJs> tableDefine = new ArrayList<TableColumnInfoJs>();
-        
+
         /** メイン処理 */
         tableDefine.add(FACILITY_ID, new TableColumnInfoJs(
-                WebMessages.getString("facility.id", locale), 
-                TableColumnInfoJs.FACILITY_ID, 100, SWT.LEFT, 
+                WebMessages.getString("facility.id", locale),
+                TableColumnInfoJs.FACILITY_ID, 100, SWT.LEFT,
                 RepositoryMappingUtil.getNodeName(FACILITY_ID)));
         tableDefine.add(FACILITY_NAME, new TableColumnInfoJs(
                 WebMessages.getString("facility.name", locale),
-                TableColumnInfoJs.FACILITY_NAME, 150, SWT.LEFT, 
+                TableColumnInfoJs.FACILITY_NAME, 150, SWT.LEFT,
                 RepositoryMappingUtil.getNodeName(FACILITY_NAME)));
         tableDefine.add(PLATFORM, new TableColumnInfoJs(
-                WebMessages.getString("platform.family.name",locale), 
+                WebMessages.getString("platform.family.name",locale),
                 TableColumnInfoJs.NONE, 120, SWT.LEFT,
                 RepositoryMappingUtil.getNodeName(PLATFORM)));
         tableDefine.add(IP_ADDRESS, new TableColumnInfoJs(
@@ -79,10 +82,16 @@ public class GetNodeListTableDefine {
                 TableColumnInfoJs.NONE, 120, SWT.LEFT,
                 RepositoryMappingUtil.getNodeName(IP_ADDRESS)));
         tableDefine.add(DESCRIPTION, new TableColumnInfoJs(
-                WebMessages.getString("description",locale), 
+                WebMessages.getString("description",locale),
                 TableColumnInfoJs.NONE, 200, SWT.LEFT,
                 RepositoryMappingUtil.getNodeName(DESCRIPTION)));
-
+        if (isManagerIpRequired) {
+            tableDefine.add(
+                    MANAGER,
+                    new TableColumnInfoJs(WebMessages.getString("manager",
+                            locale), TableColumnInfoJs.NONE, 150, SWT.LEFT,
+                            RepositoryMappingUtil.getNodeName(MANAGER)));
+        }
         return tableDefine;
     }
 }
\ No newline at end of file
