@@ -40,6 +40,9 @@ public class FacilityTreeBean extends TreeInfo implements Serializable {
     private boolean valid;
     
     private String key;
+    
+    /** マネージャのIPアドレス */
+    private String managerIp = "";
 
     private ArrayList<FacilityTreeBean> children;
 
@@ -112,4 +115,12 @@ public class FacilityTreeBean extends TreeInfo implements Serializable {
     public void setValid(boolean valid) {
         this.valid = valid;
     }
+
+    public String getManagerIp() {
+        return managerIp;
+    }
+
+    public void setManagerIp(String managerIp) {
+        this.managerIp = managerIp;
+    }
 }
