@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.business;
@@ -26,24 +26,29 @@ import com.necsoft.hinemos.webclient.repository.action.GetNodeListTableDefine;
 
 /**
  * This class used to display Node List Business
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class GetNodeListTableDefineBusiness {
 
-    public ArrayList<TableColumnInfoJs> getNodeListTableDefine(Locale locale)
+    public ArrayList<TableColumnInfoJs> getNodeListTableDefine(Locale locale, boolean isManagerIpRequired)
             throws HinemosWebException {
         // 中間変数を宣言
         ArrayList<TableColumnInfoJs> tblDefine = null;
         // ...(GetNodeListTableDefine)を取得
-        tblDefine = GetNodeListTableDefine.get(locale);
+        tblDefine = GetNodeListTableDefine.get(locale, isManagerIpRequired);
         // ...テーブルヘッダー定義データの項目数チェック
-        if (tblDefine.size() != RepositoryConstants.NODE_LIST_TABLE_HEADER_NUM) {
-            // 項目数が不足の場合
-            throw new HinemosWebHeaderInvalidException("exception.header.number");
+        if (isManagerIpRequired) {
+            if (tblDefine.size() != RepositoryConstants.NODE_LIST_TABLE_HEADER_NUM_WITH_MANAGER) {
+                throw new HinemosWebHeaderInvalidException("exception.header.number");
+            }
+        } else {
+            if (tblDefine.size() != RepositoryConstants.NODE_LIST_TABLE_HEADER_NUM_WITHOUT_MANAGER) {
+                throw new HinemosWebHeaderInvalidException("exception.header.number");
+            }
         }
-        
+
         return tblDefine;
     }
 }
\ No newline at end of file
