@@ -1,23 +1,26 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.business;
 
 import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Set;
 
 import javax.xml.ws.WebServiceException;
 
@@ -28,22 +31,39 @@ import com.clustercontrol.ws.repository.InvalidUserPass_Exception;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
-import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
 import com.necsoft.hinemos.webclient.repository.action.GetNodeScopeTableDefine;
 import com.necsoft.hinemos.webclient.repository.form.NodeScopeForm;
 import com.necsoft.hinemos.webclient.repository.util.ConvertListUtil;
 import com.necsoft.hinemos.webclient.repository.util.RepositoryEndpointWrapper;
 import com.necsoft.hinemos.webclient.util.EndpointManager;
+import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * This class used for get data of NodeScope view
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
 public class GetNodeScopeBusiness {
 
-    public ArrayList<ArrayList<Object>> getNodeScope(NodeScopeForm form, EndpointManager endpointManager) throws HinemosWebException {
+    public ArrayList<ArrayList<Object>> getNodeScope(NodeScopeForm form, LinkedHashMap<String, LoginManager> loginManagerMap) throws HinemosWebException {
+        String facilityId = form.getFacilityId();
+        String managerIpForSearch = form.getManagerIpForSearch();
+        if (facilityId == null || facilityId.trim().isEmpty()) {
+            return new ArrayList<ArrayList<Object>>();
+        } else {
+            if (managerIpForSearch == null || managerIpForSearch.trim().isEmpty()) {
+                Set<String> managerIpSet = loginManagerMap.keySet();
+                Iterator<String> iterator = managerIpSet.iterator();
+                while (iterator.hasNext()) {
+                    String managerIp = iterator.next();
+                    return getNodeScope(form, loginManagerMap.get(managerIp).endpointManager);
+                }
+            }
+            return getNodeScope(form, loginManagerMap.get(managerIpForSearch).endpointManager);
+        }
+    }
+    private ArrayList<ArrayList<Object>> getNodeScope(NodeScopeForm form, EndpointManager endpointManager) throws HinemosWebException {
 
         List<String> listInfoData = null;
         try {
@@ -61,19 +81,18 @@ public class GetNodeScopeBusiness {
         } catch (WebServiceException e) {
             // Hinemosマネージャより応答がありませんでした。ログアウトします。
             throw new HinemosWebException("message.force.disconnect");
-        } 
-            
+        }
+
         ArrayList<ArrayList<Object>> list = ConvertListUtil.convertNodeScopeInfoToList(listInfoData);
-        
+
         // Sanitize
         ConvertListUtil.sanitizeNodeScopeInfoData(list);
-        
+
         // Sort data
-        DataProcess.sortData(form, list,
+        DataProcess.doSortListDataInfo(form, list,
                 GetNodeScopeTableDefine.SORT_COLUMN_INDEX,
-                GetNodeScopeTableDefine.SORT_ORDER,
-                RepositoryConstants.NODE_SCOPE_TABLE_HEADER_NUM);
-        
+                GetNodeScopeTableDefine.SORT_ORDER);
+
         return list;
     }
 }
\ No newline at end of file
