@@ -1,27 +1,29 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.servlet;
 
 import java.io.IOException;
+import java.util.LinkedHashMap;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
+
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
@@ -34,7 +36,7 @@ import com.necsoft.hinemos.webclient.util.LoginManager;
 
 /**
  * ファシリティ一覧取得するクラス
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -44,6 +46,7 @@ public class GetFacilityListServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetFacilityListServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request, HttpServletResponse response)
             throws ServletException, IOException, HinemosWebAccessException {
 
@@ -51,12 +54,14 @@ public class GetFacilityListServlet extends CommonServlet {
         try {
             //get loginManager session
             HttpSession session = request.getSession(true);
-            LoginManager loginManager = null;
+            boolean isRepositoryTree = "/get_facility_tree".equalsIgnoreCase(request.getServletPath());
+
             synchronized(session) {
-                loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-                
+                @SuppressWarnings("unchecked")
+                LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
                 GetFacilityListBusiness facility = new GetFacilityListBusiness();
-                result = facility.getFacilityTree(loginManager.endpointManager);
+                result = facility.getFacilityTree(loginManagerMap, isRepositoryTree);
+                return result;
             }
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
