@@ -1,22 +1,25 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.servlet;
 
 import java.io.IOException;
+import java.util.LinkedHashMap;
+import java.util.Set;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -38,7 +41,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for display data of NodeProperty view
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -48,6 +51,7 @@ public class GetNodePropertyServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetNodePropertyServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request, HttpServletResponse response)
             throws ServletException, IOException, HinemosWebAccessException {
 
@@ -56,7 +60,7 @@ public class GetNodePropertyServlet extends CommonServlet {
         try {
             //get data
             Property propertyNode = getNodeProperty(request);
-            
+
             //convert to json
             result = DataProcess.doConvertNodePropertyToJson(propertyNode.getChildren());
         } catch (HinemosWebAccessException ex) {
@@ -71,7 +75,7 @@ public class GetNodePropertyServlet extends CommonServlet {
             result = ExceptionHandlerUtils.doBuildCommonJson(
                     ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
         }
-        
+
         return result;
     }
 
@@ -80,17 +84,25 @@ public class GetNodePropertyServlet extends CommonServlet {
         NodePropertyForm form = new NodePropertyForm();
         Property result = null;
         PopulateBeanUtils.populateBean(form, request);
-                
+
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+
             GetNodePropertyBusiness business = new GetNodePropertyBusiness();
-            result = business.getNodeProperty(form, request.getLocale(), loginManager.endpointManager);
+            String managerIpForSearch = form.getManagerIpForSearch();
+            if (managerIpForSearch == null) {
+                Set<String> managerIpSet = loginManagerMap.keySet();
+                String[] managerIps = new String[managerIpSet.size()];
+                managerIpSet.toArray(managerIps);
+                result = business.getNodeProperty(form, request.getLocale(), loginManagerMap.get(managerIps[0]).endpointManager);
+            } else {
+                result = business.getNodeProperty(form, request.getLocale(), loginManagerMap.get(form.getManagerIpForSearch()).endpointManager);
+            }
         }
-        
+
         return result;
     }
 }
\ No newline at end of file
