@@ -1,23 +1,25 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -39,7 +41,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for display data of NodeScope view
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -50,6 +52,7 @@ public class GetNodeScopeServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetNodeScopeServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
@@ -59,7 +62,7 @@ public class GetNodeScopeServlet extends CommonServlet {
         try {
             //get data
             ArrayList<ArrayList<Object>> listInfoData = getNodeScope(request);
-            
+
             //convert to json
             result = DataProcess.doConvertTableContentToJson(listInfoData);
         } catch (HinemosWebAccessException ex) {
@@ -94,12 +97,11 @@ public class GetNodeScopeServlet extends CommonServlet {
         }
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
             GetNodeScopeBusiness business = new GetNodeScopeBusiness();
-            result = business.getNodeScope(form, loginManager.endpointManager);
+            result = business.getNodeScope(form, loginManagerMap);
         }
 
         return result;
