@@ -1,27 +1,31 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.servlet;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
+import java.util.List;
+
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
+
 import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
@@ -38,7 +42,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for display data of scope view
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  **/
@@ -49,20 +53,21 @@ public class GetScopeListServlet extends CommonServlet {
     private static LogUtils logUtils = LogUtils
             .getLogUtils(GetScopeListServlet.class);
 
+    @Override
     public CommonJson process(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
 
         // 中間変数を宣言
         CommonJson result = new CommonJson();
-        
+
         try {
             //get data
-            ArrayList<ArrayList<Object>> listInfoData = getScopeList(request);
-            
+            List<ArrayList<Object>> listInfoData = getScopeList(request);
+
             //convert to json
             result = DataProcess.doConvertTableContentToJson(listInfoData);
-        
+
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
@@ -81,24 +86,24 @@ public class GetScopeListServlet extends CommonServlet {
         return result;
     }
 
-    private ArrayList<ArrayList<Object>> getScopeList(HttpServletRequest request) 
+    private List<ArrayList<Object>> getScopeList(HttpServletRequest request)
         throws HinemosWebException {
         // 中間変数を宣言
         ScopeListForm form = new ScopeListForm();
-        ArrayList<ArrayList<Object>> result = null;
-        
+        List<ArrayList<Object>> result = null;
+
         PopulateBeanUtils.populateBean(form, request);
 
         //get loginManager session
         HttpSession session = request.getSession(true);
-        LoginManager loginManager = null;
         synchronized(session) {
-            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-            
+            @SuppressWarnings("unchecked")
+            LinkedHashMap<String, LoginManager> loginManagerMap = (LinkedHashMap<String, LoginManager>) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
             GetScopeListBusiness business = new GetScopeListBusiness();
-            result = business.getScopeList(form, loginManager.endpointManager);
+            result = business.getScopeList(form, loginManagerMap);
         }
-                
+
+
         return result;
     }
 }
