@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.util;
@@ -46,29 +46,29 @@ public class ConvertListUtil {
         while (itr.hasNext()) {
             ArrayList<Object> scope = new ArrayList<Object>();
             FacilityInfo scopeInfoData = itr.next();
-           
+
             // ファシリティID
             scope.add(GetScopeListTableDefine.FACILITY_ID,
                     scopeInfoData.getFacilityId());
-            
+
             // ファシリティ名
             scope.add(GetScopeListTableDefine.FACILITY_NAME,
                     scopeInfoData.getFacilityName());
-            
+
             // 説明
             scope.add(GetScopeListTableDefine.DESCRIPTION,
                     scopeInfoData.getDescription());
-                        
+
             result.add(scope);
         }
 
         return result;
     }
-    
+
     /**
      * @param list
      */
-    public static void sanitizeScopeInfoData(ArrayList<ArrayList<Object>> list) {
+    public static void sanitizeScopeInfoData(List<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             ArrayList<Object> row = list.get(count);
 
@@ -78,7 +78,7 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetScopeListTableDefine.FACILITY_NAME).toString()));
             }
-            
+
             // 説明
             if (row.get(GetScopeListTableDefine.DESCRIPTION) != null) {
                 row.set(GetScopeListTableDefine.DESCRIPTION,
@@ -87,10 +87,10 @@ public class ConvertListUtil {
             }
         }
     }
-    
+
     /**
      * This method used for convert repository of NodeInfo to array list.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2011/12/14
@@ -99,7 +99,7 @@ public class ConvertListUtil {
      * @return ArrayList<ArrayList>
      */
     public static ArrayList<ArrayList<Object>> nodeInfoListToArrayList(
-            List<NodeInfo> listInfoData) {
+            List<NodeInfo> listInfoData, String managerIp) {
 
         ArrayList<ArrayList<Object>> result = new ArrayList<ArrayList<Object>>();
         Iterator<NodeInfo> itr = listInfoData.iterator();
@@ -107,7 +107,7 @@ public class ConvertListUtil {
         while (itr.hasNext()) {
             ArrayList<Object> node = new ArrayList<Object>();
             NodeInfo nodeInfoData = itr.next();
-            
+
             // ファシリティID
             node.add(GetNodeListTableDefine.FACILITY_ID,
                     nodeInfoData.getFacilityId());
@@ -125,21 +125,25 @@ public class ConvertListUtil {
                 // IPアドレス v4
                 node.add(GetNodeListTableDefine.IP_ADDRESS,
                         nodeInfoData.getIpAddressV4());
-            }   
+            }
             // 説明
             node.add(GetNodeListTableDefine.DESCRIPTION,
                     nodeInfoData.getDescription());
 
+            if (managerIp != null) {
+                // マネージャIP
+                node.add(GetNodeListTableDefine.MANAGER, managerIp);
+            }
             result.add(node);
         }
 
         return result;
     }
-    
+
     /**
      * @param list
      */
-    public static void sanitizeNodeInfoData(ArrayList<ArrayList<Object>> list) {
+    public static void sanitizeNodeInfoData(List<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             ArrayList<Object> row = list.get(count);
 
@@ -148,7 +152,7 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetNodeListTableDefine.FACILITY_NAME).toString()));
             }
-            
+
             if (row.get(GetNodeListTableDefine.DESCRIPTION) != null) {
                 row.set(GetNodeListTableDefine.DESCRIPTION,
                         StringEscapeUtils.escapeHtml4(row.get(
@@ -156,9 +160,9 @@ public class ConvertListUtil {
             }
         }
     }
-    
+
     public static ArrayList<ArrayList<Object>> agentInfoListToArrayList(
-            List<AgentStatusInfo> list) {
+            List<AgentStatusInfo> list, String managerIp) {
 
         ArrayList<ArrayList<Object>> ret = new ArrayList<ArrayList<Object>>();
         Iterator<AgentStatusInfo> itr = list.iterator();
@@ -166,28 +170,32 @@ public class ConvertListUtil {
         while (itr.hasNext()) {
             ArrayList<Object> agent = new ArrayList<Object>();
             AgentStatusInfo agentInfoData = itr.next();
-            
+
             agent.add(GetAgentListTableDefine.FACILITY_ID,
                     agentInfoData.getFacilityId());
-            
+
             agent.add(GetAgentListTableDefine.FACILITY_NAME,
                     agentInfoData.getFacilityName());
-            
+
             agent.add(GetAgentListTableDefine.STARTUP_TIME,
                     agentInfoData.getStartupTime());
-            
+
             agent.add(GetAgentListTableDefine.LAST_LOGIN,
                     agentInfoData.getLastLogin());
-            
+
             agent.add(GetAgentListTableDefine.NEW_OLD,
                     agentInfoData.isNewFlag());
-            
+
+            if (managerIp != null) {
+                // マネージャIP
+                agent.add(GetAgentListTableDefine.MANAGER, managerIp);
+            }
             ret.add(agent);
         }
 
         return ret;
     }
-    
+
     public static void sanitizeAgentInfoData(ArrayList<ArrayList<Object>> list) {
         for (int count = 0; count < list.size(); count++) {
             ArrayList<Object> row = list.get(count);
@@ -197,7 +205,7 @@ public class ConvertListUtil {
                         StringEscapeUtils.escapeHtml4(row.get(
                                 GetAgentListTableDefine.FACILITY_ID).toString()));
             }
-            
+
             if (row.get(GetAgentListTableDefine.FACILITY_NAME) != null) {
                 row.set(GetAgentListTableDefine.FACILITY_NAME,
                         StringEscapeUtils.escapeHtml4(row.get(
@@ -205,10 +213,10 @@ public class ConvertListUtil {
             }
         }
     }
-    
+
     /**
      * This method used for convert repository of NodeScopeInfo to array list.
-     * 
+     *
      * @author hungcv
      * @version 1.0
      * @since 2011/12/14
@@ -223,13 +231,13 @@ public class ConvertListUtil {
         // Set rows
         for (int countRow = 0; countRow < listInfoData.size(); countRow++) {
             ArrayList<Object> infoData = new ArrayList<Object>();
-            infoData.add(GetNodeScopeTableDefine.SCOPE, 
+            infoData.add(GetNodeScopeTableDefine.SCOPE,
                     listInfoData.get(countRow) + "");
             result.add(infoData);
         }
         return result;
     }
-    
+
     /**
      * @param list
      */
