@@ -1,63 +1,47 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.repository.util;
 
-import java.util.HashMap;
+import java.util.Iterator;
 import java.util.Locale;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import java.util.Set;
+
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.repository.bean.NodeFilterConstant;
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.lang.WebMessages;
-import com.necsoft.hinemos.webclient.util.PropertyUtil;
+import com.necsoft.hinemos.webclient.repository.RepositoryConstants;
 
 /**
  * ノードフィルタ用プロパティを作成するクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
 public class NodeFilterProperty {
 
-    private static Log m_log = LogFactory.getLog(NodeFilterProperty.class);
-
-    /** ----- 初期値キャッシュ ----- */
-    private static HashMap<Locale, Property> cachedInitProperty = null;
-
-    static {
-        cachedInitProperty = new HashMap<Locale, Property>();
-    }
-
     /**
      * ノードフィルタ用プロパティを返します。
-     * 
+     *
      * @param locale
      * @return ノードフィルタ用プロパティ
      */
-    public static Property getProperty(Locale locale) {
-
-        // 初期値のキャッシュが存在すれば、それを返す
-        if (cachedInitProperty.containsKey(locale)) {
-            m_log.debug("using a initial property of node's filter to cache. (locale = "
-                    + locale + ")");
-            return PropertyUtil.copy(cachedInitProperty.get(locale));
-        }
+    public static Property getProperty(Locale locale, Set<String> managerIpSet) {
 
         // ファシリティID
         Property facilityId = new Property(NodeFilterConstant.FACILITY_ID,
@@ -109,6 +93,29 @@ public class NodeFilterProperty {
                 WebMessages.getString("maintenance", locale),
                 PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 
+        // マネージャ列でフィルタ
+        Property m_manager = null;
+        if (managerIpSet.size() > 1) {
+            m_manager = new Property(
+                    RepositoryConstants.FILTER_CONDITION_ID_MANAGER,
+                    WebMessages.getString("manager", locale),
+                    PropertyConstant.EDITOR_SELECT);
+
+            // ログインしたマネージャのIPアドレスすべてを追加
+            Object[][] managerIpValues = new Object[2][];
+            String[] managerIps = new String[managerIpSet.size() + 1];
+            managerIps[0] = "";
+            Iterator<String> iterator = managerIpSet.iterator();
+            for (int i = 1; iterator.hasNext(); i++) {
+                managerIps[i] = iterator.next();
+            }
+            managerIpValues[0] = managerIps;
+            managerIpValues[1] = managerIps;
+            m_manager.setSelectValues(managerIpValues);
+            m_manager.setValue("");
+            m_manager.setModify(PropertyConstant.MODIFY_OK);
+        }
+
         // 値を初期化
         facilityId.setValue("");
         facilityName.setValue("");
@@ -149,6 +156,9 @@ public class NodeFilterProperty {
         property.addChildren(network);
         property.addChildren(os);
         property.addChildren(maintenance);
+        if (m_manager != null) {
+            property.addChildren(m_manager);
+        }
 
         // ネットワークツリー
         network.removeChildren();
@@ -165,11 +175,6 @@ public class NodeFilterProperty {
         maintenance.addChildren(administrator);
         maintenance.addChildren(contact);
 
-        // 初期値をキャッシュに登録（次回から高速化に初期値を取得）
-        m_log.info("adding a initial property of user's filter to cache. (locale = "
-                + locale + ")");
-        cachedInitProperty.put(locale, PropertyUtil.copy(property));
-
         return property;
     }
 }
