@@ -32,6 +32,7 @@ import com.clustercontrol.ws.repository.InvalidUserPass_Exception;
 import com.clustercontrol.ws.repository.NodeInfo;
 import com.clustercontrol.ws.repository.RepositoryEndpoint;
 import com.clustercontrol.ws.repository.RepositoryTableInfo;
+import com.necsoft.hinemos.webclient.bean.FacilityConstant;
 import com.necsoft.hinemos.webclient.util.EndpointManager;
 import com.necsoft.hinemos.webclient.util.EndpointManager.EndpointSetting;
 
@@ -239,7 +240,7 @@ public class RepositoryEndpointWrapper {
     }
 
     public static FacilityTreeItem getFacilityTree(
-            EndpointManager endpointManager) throws HinemosUnknown_Exception,
+            EndpointManager endpointManager, String managerIp) throws HinemosUnknown_Exception,
             InvalidRole_Exception, InvalidUserPass_Exception, WebServiceException {
         WebServiceException wse = null;
         for (EndpointSetting endpointSetting : endpointManager
@@ -248,7 +249,7 @@ public class RepositoryEndpointWrapper {
                 RepositoryEndpoint endpoint = (RepositoryEndpoint) endpointSetting
                         .getEndpoint();
                 FacilityTreeItem item = endpoint.getFacilityTree();
-                setTreeParent(item);
+                setTreeParent(item, managerIp);
                 return item;
             } catch (WebServiceException e) {
                 wse = e;
@@ -259,11 +260,20 @@ public class RepositoryEndpointWrapper {
         throw wse;
     }
 
-    public static void setTreeParent(FacilityTreeItem item) {
+    private static void setTreeParent(FacilityTreeItem item, String managerIp) {
+        FacilityInfo facilityInfo = item.getData();
+        // マルチログインの場合のみ、IPを追加。なお、「スコープ」を「マネージャ」に変更
+        String facilityName = facilityInfo.getFacilityName();
+        if (managerIp != null && FacilityConstant.STRING_SCOPE.equals(facilityName)) {
+            facilityInfo.setFacilityName(FacilityConstant.STRING_MANAGER + " (" + managerIp + ")");
+        } else {
+            facilityInfo.setFacilityName(facilityName);
+        }
+        item.setData(facilityInfo);
         List<FacilityTreeItem> children = item.getChildren();
         for (FacilityTreeItem child : children) {
             child.setParent(item);
-            setTreeParent(child);
+            setTreeParent(child, managerIp);
         }
     }
 
