@@ -1,17 +1,17 @@
 /*
- 
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
- 
+
+Copyright (C) NEC Corporation 2012. All Rights Reserved.
+Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
+
 */
 
 package com.necsoft.hinemos.webclient.servlet;
@@ -65,12 +65,13 @@ public abstract class CommonServlet extends HttpServlet {
 
     /**
      * Handles the HTTP <code>POST</code> method.
-     * 
+     *
      * @param request
      *            servlet request
      * @param response
      *            servlet response
      */
+    @Override
     protected void doPost(HttpServletRequest request,
             HttpServletResponse response) throws ServletException, IOException {
         doGet(request, response);
@@ -79,12 +80,13 @@ public abstract class CommonServlet extends HttpServlet {
     /**
      * Processes requests for both HTTP <code>GET</code> and <code>POST</code>
      * methods.
-     * 
+     *
      * @param request
      *            servlet request
      * @param response
      *            servlet response
      */
+    @Override
     protected void doGet(HttpServletRequest request,
             HttpServletResponse response) {
         HttpSession session = request.getSession(true);
@@ -104,9 +106,9 @@ public abstract class CommonServlet extends HttpServlet {
                     }
                     CommonJson result = ExceptionHandlerUtils.doBuildCommonJson(
                             ExceptionHandlerUtils.LEVEL_ERROR, "message.sessiontimeout", request.getLocale());
-                    
+
                     Object errMsg = result.getMessage();
-                    if (errMsg != null && errMsg instanceof String) 
+                    if (errMsg != null && errMsg instanceof String)
                     {
                         errMsg = StringEscapeUtils.escapeHtml4((String) errMsg);
                         result.setMessage(errMsg);
@@ -156,7 +158,7 @@ public abstract class CommonServlet extends HttpServlet {
 
     /**
      * Get information of url after selvetPath
-     * 
+     *
      * @param request
      * @return
      */
@@ -175,6 +177,7 @@ public abstract class CommonServlet extends HttpServlet {
     /**
      * Initializes the servlet.
      */
+    @Override
     public void init(ServletConfig config) throws ServletException {
         super.init(config);
     }
@@ -182,6 +185,7 @@ public abstract class CommonServlet extends HttpServlet {
     /**
      * Destroys the servlet.
      */
+    @Override
     public void destroy() {
         super.destroy();
     }
@@ -199,7 +203,7 @@ public abstract class CommonServlet extends HttpServlet {
         } else {
             zone = TimeZone.getTimeZone(TimeZoneID);
         }
-        
+
         // Get parameter
         for (int count = 0; count < listCondElement.length; count++) {
             Property condElement = (Property) listCondElement[count];
@@ -233,7 +237,7 @@ public abstract class CommonServlet extends HttpServlet {
             }
         }
     }
-    
+
     public static List<String> getBypassList() {
         return listBypass;
     }
@@ -245,16 +249,22 @@ public abstract class CommonServlet extends HttpServlet {
         return getBypassList().contains(servletPath);
     }
 
-    protected UserBean getUserBean(HttpServletRequest request) {
-        return (UserBean) request.getSession(true).getAttribute(
+    @SuppressWarnings("unchecked")
+    protected List<UserBean> getUserBean(HttpServletRequest request) {
+        return (List<UserBean>) request.getSession(true).getAttribute(
                 AccessControlConstants.USER_BEAN);
     }
 
-    protected String getUserName(HttpServletRequest request) {
-        UserBean userbean = getUserBean(request);
-        if (userbean == null) {
-            return null;
+    protected String getUserName(HttpServletRequest request, String managerIp) {
+        List<UserBean> userBeanList = getUserBean(request);
+        for (UserBean userBean : userBeanList) {
+            // シングルログインの場合
+            if (managerIp == null) {
+                return userBean.getUserName();
+            } else if (userBean.getManagerIp().equals(managerIp)) {
+                return userBean.getUserName();
+            }
         }
-        return userbean.getUserName();
+        return null;
     }
 }
\ No newline at end of file
